// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_RN_LOW_REGISTERS_IN_IT_BLOCK_TST_T32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_RN_LOW_REGISTERS_IN_IT_BLOCK_TST_T32_H_

const byte kInstruction_tst_eq_r0_r0[] = {
  0x08, 0xbf, 0x00, 0x42 // It eq; tst eq r0 r0
};
const byte kInstruction_tst_eq_r0_r1[] = {
  0x08, 0xbf, 0x08, 0x42 // It eq; tst eq r0 r1
};
const byte kInstruction_tst_eq_r0_r2[] = {
  0x08, 0xbf, 0x10, 0x42 // It eq; tst eq r0 r2
};
const byte kInstruction_tst_eq_r0_r3[] = {
  0x08, 0xbf, 0x18, 0x42 // It eq; tst eq r0 r3
};
const byte kInstruction_tst_eq_r0_r4[] = {
  0x08, 0xbf, 0x20, 0x42 // It eq; tst eq r0 r4
};
const byte kInstruction_tst_eq_r0_r5[] = {
  0x08, 0xbf, 0x28, 0x42 // It eq; tst eq r0 r5
};
const byte kInstruction_tst_eq_r0_r6[] = {
  0x08, 0xbf, 0x30, 0x42 // It eq; tst eq r0 r6
};
const byte kInstruction_tst_eq_r0_r7[] = {
  0x08, 0xbf, 0x38, 0x42 // It eq; tst eq r0 r7
};
const byte kInstruction_tst_eq_r1_r0[] = {
  0x08, 0xbf, 0x01, 0x42 // It eq; tst eq r1 r0
};
const byte kInstruction_tst_eq_r1_r1[] = {
  0x08, 0xbf, 0x09, 0x42 // It eq; tst eq r1 r1
};
const byte kInstruction_tst_eq_r1_r2[] = {
  0x08, 0xbf, 0x11, 0x42 // It eq; tst eq r1 r2
};
const byte kInstruction_tst_eq_r1_r3[] = {
  0x08, 0xbf, 0x19, 0x42 // It eq; tst eq r1 r3
};
const byte kInstruction_tst_eq_r1_r4[] = {
  0x08, 0xbf, 0x21, 0x42 // It eq; tst eq r1 r4
};
const byte kInstruction_tst_eq_r1_r5[] = {
  0x08, 0xbf, 0x29, 0x42 // It eq; tst eq r1 r5
};
const byte kInstruction_tst_eq_r1_r6[] = {
  0x08, 0xbf, 0x31, 0x42 // It eq; tst eq r1 r6
};
const byte kInstruction_tst_eq_r1_r7[] = {
  0x08, 0xbf, 0x39, 0x42 // It eq; tst eq r1 r7
};
const byte kInstruction_tst_eq_r2_r0[] = {
  0x08, 0xbf, 0x02, 0x42 // It eq; tst eq r2 r0
};
const byte kInstruction_tst_eq_r2_r1[] = {
  0x08, 0xbf, 0x0a, 0x42 // It eq; tst eq r2 r1
};
const byte kInstruction_tst_eq_r2_r2[] = {
  0x08, 0xbf, 0x12, 0x42 // It eq; tst eq r2 r2
};
const byte kInstruction_tst_eq_r2_r3[] = {
  0x08, 0xbf, 0x1a, 0x42 // It eq; tst eq r2 r3
};
const byte kInstruction_tst_eq_r2_r4[] = {
  0x08, 0xbf, 0x22, 0x42 // It eq; tst eq r2 r4
};
const byte kInstruction_tst_eq_r2_r5[] = {
  0x08, 0xbf, 0x2a, 0x42 // It eq; tst eq r2 r5
};
const byte kInstruction_tst_eq_r2_r6[] = {
  0x08, 0xbf, 0x32, 0x42 // It eq; tst eq r2 r6
};
const byte kInstruction_tst_eq_r2_r7[] = {
  0x08, 0xbf, 0x3a, 0x42 // It eq; tst eq r2 r7
};
const byte kInstruction_tst_eq_r3_r0[] = {
  0x08, 0xbf, 0x03, 0x42 // It eq; tst eq r3 r0
};
const byte kInstruction_tst_eq_r3_r1[] = {
  0x08, 0xbf, 0x0b, 0x42 // It eq; tst eq r3 r1
};
const byte kInstruction_tst_eq_r3_r2[] = {
  0x08, 0xbf, 0x13, 0x42 // It eq; tst eq r3 r2
};
const byte kInstruction_tst_eq_r3_r3[] = {
  0x08, 0xbf, 0x1b, 0x42 // It eq; tst eq r3 r3
};
const byte kInstruction_tst_eq_r3_r4[] = {
  0x08, 0xbf, 0x23, 0x42 // It eq; tst eq r3 r4
};
const byte kInstruction_tst_eq_r3_r5[] = {
  0x08, 0xbf, 0x2b, 0x42 // It eq; tst eq r3 r5
};
const byte kInstruction_tst_eq_r3_r6[] = {
  0x08, 0xbf, 0x33, 0x42 // It eq; tst eq r3 r6
};
const byte kInstruction_tst_eq_r3_r7[] = {
  0x08, 0xbf, 0x3b, 0x42 // It eq; tst eq r3 r7
};
const byte kInstruction_tst_eq_r4_r0[] = {
  0x08, 0xbf, 0x04, 0x42 // It eq; tst eq r4 r0
};
const byte kInstruction_tst_eq_r4_r1[] = {
  0x08, 0xbf, 0x0c, 0x42 // It eq; tst eq r4 r1
};
const byte kInstruction_tst_eq_r4_r2[] = {
  0x08, 0xbf, 0x14, 0x42 // It eq; tst eq r4 r2
};
const byte kInstruction_tst_eq_r4_r3[] = {
  0x08, 0xbf, 0x1c, 0x42 // It eq; tst eq r4 r3
};
const byte kInstruction_tst_eq_r4_r4[] = {
  0x08, 0xbf, 0x24, 0x42 // It eq; tst eq r4 r4
};
const byte kInstruction_tst_eq_r4_r5[] = {
  0x08, 0xbf, 0x2c, 0x42 // It eq; tst eq r4 r5
};
const byte kInstruction_tst_eq_r4_r6[] = {
  0x08, 0xbf, 0x34, 0x42 // It eq; tst eq r4 r6
};
const byte kInstruction_tst_eq_r4_r7[] = {
  0x08, 0xbf, 0x3c, 0x42 // It eq; tst eq r4 r7
};
const byte kInstruction_tst_eq_r5_r0[] = {
  0x08, 0xbf, 0x05, 0x42 // It eq; tst eq r5 r0
};
const byte kInstruction_tst_eq_r5_r1[] = {
  0x08, 0xbf, 0x0d, 0x42 // It eq; tst eq r5 r1
};
const byte kInstruction_tst_eq_r5_r2[] = {
  0x08, 0xbf, 0x15, 0x42 // It eq; tst eq r5 r2
};
const byte kInstruction_tst_eq_r5_r3[] = {
  0x08, 0xbf, 0x1d, 0x42 // It eq; tst eq r5 r3
};
const byte kInstruction_tst_eq_r5_r4[] = {
  0x08, 0xbf, 0x25, 0x42 // It eq; tst eq r5 r4
};
const byte kInstruction_tst_eq_r5_r5[] = {
  0x08, 0xbf, 0x2d, 0x42 // It eq; tst eq r5 r5
};
const byte kInstruction_tst_eq_r5_r6[] = {
  0x08, 0xbf, 0x35, 0x42 // It eq; tst eq r5 r6
};
const byte kInstruction_tst_eq_r5_r7[] = {
  0x08, 0xbf, 0x3d, 0x42 // It eq; tst eq r5 r7
};
const byte kInstruction_tst_eq_r6_r0[] = {
  0x08, 0xbf, 0x06, 0x42 // It eq; tst eq r6 r0
};
const byte kInstruction_tst_eq_r6_r1[] = {
  0x08, 0xbf, 0x0e, 0x42 // It eq; tst eq r6 r1
};
const byte kInstruction_tst_eq_r6_r2[] = {
  0x08, 0xbf, 0x16, 0x42 // It eq; tst eq r6 r2
};
const byte kInstruction_tst_eq_r6_r3[] = {
  0x08, 0xbf, 0x1e, 0x42 // It eq; tst eq r6 r3
};
const byte kInstruction_tst_eq_r6_r4[] = {
  0x08, 0xbf, 0x26, 0x42 // It eq; tst eq r6 r4
};
const byte kInstruction_tst_eq_r6_r5[] = {
  0x08, 0xbf, 0x2e, 0x42 // It eq; tst eq r6 r5
};
const byte kInstruction_tst_eq_r6_r6[] = {
  0x08, 0xbf, 0x36, 0x42 // It eq; tst eq r6 r6
};
const byte kInstruction_tst_eq_r6_r7[] = {
  0x08, 0xbf, 0x3e, 0x42 // It eq; tst eq r6 r7
};
const byte kInstruction_tst_eq_r7_r0[] = {
  0x08, 0xbf, 0x07, 0x42 // It eq; tst eq r7 r0
};
const byte kInstruction_tst_eq_r7_r1[] = {
  0x08, 0xbf, 0x0f, 0x42 // It eq; tst eq r7 r1
};
const byte kInstruction_tst_eq_r7_r2[] = {
  0x08, 0xbf, 0x17, 0x42 // It eq; tst eq r7 r2
};
const byte kInstruction_tst_eq_r7_r3[] = {
  0x08, 0xbf, 0x1f, 0x42 // It eq; tst eq r7 r3
};
const byte kInstruction_tst_eq_r7_r4[] = {
  0x08, 0xbf, 0x27, 0x42 // It eq; tst eq r7 r4
};
const byte kInstruction_tst_eq_r7_r5[] = {
  0x08, 0xbf, 0x2f, 0x42 // It eq; tst eq r7 r5
};
const byte kInstruction_tst_eq_r7_r6[] = {
  0x08, 0xbf, 0x37, 0x42 // It eq; tst eq r7 r6
};
const byte kInstruction_tst_eq_r7_r7[] = {
  0x08, 0xbf, 0x3f, 0x42 // It eq; tst eq r7 r7
};
const byte kInstruction_tst_ne_r0_r0[] = {
  0x18, 0xbf, 0x00, 0x42 // It ne; tst ne r0 r0
};
const byte kInstruction_tst_ne_r0_r1[] = {
  0x18, 0xbf, 0x08, 0x42 // It ne; tst ne r0 r1
};
const byte kInstruction_tst_ne_r0_r2[] = {
  0x18, 0xbf, 0x10, 0x42 // It ne; tst ne r0 r2
};
const byte kInstruction_tst_ne_r0_r3[] = {
  0x18, 0xbf, 0x18, 0x42 // It ne; tst ne r0 r3
};
const byte kInstruction_tst_ne_r0_r4[] = {
  0x18, 0xbf, 0x20, 0x42 // It ne; tst ne r0 r4
};
const byte kInstruction_tst_ne_r0_r5[] = {
  0x18, 0xbf, 0x28, 0x42 // It ne; tst ne r0 r5
};
const byte kInstruction_tst_ne_r0_r6[] = {
  0x18, 0xbf, 0x30, 0x42 // It ne; tst ne r0 r6
};
const byte kInstruction_tst_ne_r0_r7[] = {
  0x18, 0xbf, 0x38, 0x42 // It ne; tst ne r0 r7
};
const byte kInstruction_tst_ne_r1_r0[] = {
  0x18, 0xbf, 0x01, 0x42 // It ne; tst ne r1 r0
};
const byte kInstruction_tst_ne_r1_r1[] = {
  0x18, 0xbf, 0x09, 0x42 // It ne; tst ne r1 r1
};
const byte kInstruction_tst_ne_r1_r2[] = {
  0x18, 0xbf, 0x11, 0x42 // It ne; tst ne r1 r2
};
const byte kInstruction_tst_ne_r1_r3[] = {
  0x18, 0xbf, 0x19, 0x42 // It ne; tst ne r1 r3
};
const byte kInstruction_tst_ne_r1_r4[] = {
  0x18, 0xbf, 0x21, 0x42 // It ne; tst ne r1 r4
};
const byte kInstruction_tst_ne_r1_r5[] = {
  0x18, 0xbf, 0x29, 0x42 // It ne; tst ne r1 r5
};
const byte kInstruction_tst_ne_r1_r6[] = {
  0x18, 0xbf, 0x31, 0x42 // It ne; tst ne r1 r6
};
const byte kInstruction_tst_ne_r1_r7[] = {
  0x18, 0xbf, 0x39, 0x42 // It ne; tst ne r1 r7
};
const byte kInstruction_tst_ne_r2_r0[] = {
  0x18, 0xbf, 0x02, 0x42 // It ne; tst ne r2 r0
};
const byte kInstruction_tst_ne_r2_r1[] = {
  0x18, 0xbf, 0x0a, 0x42 // It ne; tst ne r2 r1
};
const byte kInstruction_tst_ne_r2_r2[] = {
  0x18, 0xbf, 0x12, 0x42 // It ne; tst ne r2 r2
};
const byte kInstruction_tst_ne_r2_r3[] = {
  0x18, 0xbf, 0x1a, 0x42 // It ne; tst ne r2 r3
};
const byte kInstruction_tst_ne_r2_r4[] = {
  0x18, 0xbf, 0x22, 0x42 // It ne; tst ne r2 r4
};
const byte kInstruction_tst_ne_r2_r5[] = {
  0x18, 0xbf, 0x2a, 0x42 // It ne; tst ne r2 r5
};
const byte kInstruction_tst_ne_r2_r6[] = {
  0x18, 0xbf, 0x32, 0x42 // It ne; tst ne r2 r6
};
const byte kInstruction_tst_ne_r2_r7[] = {
  0x18, 0xbf, 0x3a, 0x42 // It ne; tst ne r2 r7
};
const byte kInstruction_tst_ne_r3_r0[] = {
  0x18, 0xbf, 0x03, 0x42 // It ne; tst ne r3 r0
};
const byte kInstruction_tst_ne_r3_r1[] = {
  0x18, 0xbf, 0x0b, 0x42 // It ne; tst ne r3 r1
};
const byte kInstruction_tst_ne_r3_r2[] = {
  0x18, 0xbf, 0x13, 0x42 // It ne; tst ne r3 r2
};
const byte kInstruction_tst_ne_r3_r3[] = {
  0x18, 0xbf, 0x1b, 0x42 // It ne; tst ne r3 r3
};
const byte kInstruction_tst_ne_r3_r4[] = {
  0x18, 0xbf, 0x23, 0x42 // It ne; tst ne r3 r4
};
const byte kInstruction_tst_ne_r3_r5[] = {
  0x18, 0xbf, 0x2b, 0x42 // It ne; tst ne r3 r5
};
const byte kInstruction_tst_ne_r3_r6[] = {
  0x18, 0xbf, 0x33, 0x42 // It ne; tst ne r3 r6
};
const byte kInstruction_tst_ne_r3_r7[] = {
  0x18, 0xbf, 0x3b, 0x42 // It ne; tst ne r3 r7
};
const byte kInstruction_tst_ne_r4_r0[] = {
  0x18, 0xbf, 0x04, 0x42 // It ne; tst ne r4 r0
};
const byte kInstruction_tst_ne_r4_r1[] = {
  0x18, 0xbf, 0x0c, 0x42 // It ne; tst ne r4 r1
};
const byte kInstruction_tst_ne_r4_r2[] = {
  0x18, 0xbf, 0x14, 0x42 // It ne; tst ne r4 r2
};
const byte kInstruction_tst_ne_r4_r3[] = {
  0x18, 0xbf, 0x1c, 0x42 // It ne; tst ne r4 r3
};
const byte kInstruction_tst_ne_r4_r4[] = {
  0x18, 0xbf, 0x24, 0x42 // It ne; tst ne r4 r4
};
const byte kInstruction_tst_ne_r4_r5[] = {
  0x18, 0xbf, 0x2c, 0x42 // It ne; tst ne r4 r5
};
const byte kInstruction_tst_ne_r4_r6[] = {
  0x18, 0xbf, 0x34, 0x42 // It ne; tst ne r4 r6
};
const byte kInstruction_tst_ne_r4_r7[] = {
  0x18, 0xbf, 0x3c, 0x42 // It ne; tst ne r4 r7
};
const byte kInstruction_tst_ne_r5_r0[] = {
  0x18, 0xbf, 0x05, 0x42 // It ne; tst ne r5 r0
};
const byte kInstruction_tst_ne_r5_r1[] = {
  0x18, 0xbf, 0x0d, 0x42 // It ne; tst ne r5 r1
};
const byte kInstruction_tst_ne_r5_r2[] = {
  0x18, 0xbf, 0x15, 0x42 // It ne; tst ne r5 r2
};
const byte kInstruction_tst_ne_r5_r3[] = {
  0x18, 0xbf, 0x1d, 0x42 // It ne; tst ne r5 r3
};
const byte kInstruction_tst_ne_r5_r4[] = {
  0x18, 0xbf, 0x25, 0x42 // It ne; tst ne r5 r4
};
const byte kInstruction_tst_ne_r5_r5[] = {
  0x18, 0xbf, 0x2d, 0x42 // It ne; tst ne r5 r5
};
const byte kInstruction_tst_ne_r5_r6[] = {
  0x18, 0xbf, 0x35, 0x42 // It ne; tst ne r5 r6
};
const byte kInstruction_tst_ne_r5_r7[] = {
  0x18, 0xbf, 0x3d, 0x42 // It ne; tst ne r5 r7
};
const byte kInstruction_tst_ne_r6_r0[] = {
  0x18, 0xbf, 0x06, 0x42 // It ne; tst ne r6 r0
};
const byte kInstruction_tst_ne_r6_r1[] = {
  0x18, 0xbf, 0x0e, 0x42 // It ne; tst ne r6 r1
};
const byte kInstruction_tst_ne_r6_r2[] = {
  0x18, 0xbf, 0x16, 0x42 // It ne; tst ne r6 r2
};
const byte kInstruction_tst_ne_r6_r3[] = {
  0x18, 0xbf, 0x1e, 0x42 // It ne; tst ne r6 r3
};
const byte kInstruction_tst_ne_r6_r4[] = {
  0x18, 0xbf, 0x26, 0x42 // It ne; tst ne r6 r4
};
const byte kInstruction_tst_ne_r6_r5[] = {
  0x18, 0xbf, 0x2e, 0x42 // It ne; tst ne r6 r5
};
const byte kInstruction_tst_ne_r6_r6[] = {
  0x18, 0xbf, 0x36, 0x42 // It ne; tst ne r6 r6
};
const byte kInstruction_tst_ne_r6_r7[] = {
  0x18, 0xbf, 0x3e, 0x42 // It ne; tst ne r6 r7
};
const byte kInstruction_tst_ne_r7_r0[] = {
  0x18, 0xbf, 0x07, 0x42 // It ne; tst ne r7 r0
};
const byte kInstruction_tst_ne_r7_r1[] = {
  0x18, 0xbf, 0x0f, 0x42 // It ne; tst ne r7 r1
};
const byte kInstruction_tst_ne_r7_r2[] = {
  0x18, 0xbf, 0x17, 0x42 // It ne; tst ne r7 r2
};
const byte kInstruction_tst_ne_r7_r3[] = {
  0x18, 0xbf, 0x1f, 0x42 // It ne; tst ne r7 r3
};
const byte kInstruction_tst_ne_r7_r4[] = {
  0x18, 0xbf, 0x27, 0x42 // It ne; tst ne r7 r4
};
const byte kInstruction_tst_ne_r7_r5[] = {
  0x18, 0xbf, 0x2f, 0x42 // It ne; tst ne r7 r5
};
const byte kInstruction_tst_ne_r7_r6[] = {
  0x18, 0xbf, 0x37, 0x42 // It ne; tst ne r7 r6
};
const byte kInstruction_tst_ne_r7_r7[] = {
  0x18, 0xbf, 0x3f, 0x42 // It ne; tst ne r7 r7
};
const byte kInstruction_tst_cs_r0_r0[] = {
  0x28, 0xbf, 0x00, 0x42 // It cs; tst cs r0 r0
};
const byte kInstruction_tst_cs_r0_r1[] = {
  0x28, 0xbf, 0x08, 0x42 // It cs; tst cs r0 r1
};
const byte kInstruction_tst_cs_r0_r2[] = {
  0x28, 0xbf, 0x10, 0x42 // It cs; tst cs r0 r2
};
const byte kInstruction_tst_cs_r0_r3[] = {
  0x28, 0xbf, 0x18, 0x42 // It cs; tst cs r0 r3
};
const byte kInstruction_tst_cs_r0_r4[] = {
  0x28, 0xbf, 0x20, 0x42 // It cs; tst cs r0 r4
};
const byte kInstruction_tst_cs_r0_r5[] = {
  0x28, 0xbf, 0x28, 0x42 // It cs; tst cs r0 r5
};
const byte kInstruction_tst_cs_r0_r6[] = {
  0x28, 0xbf, 0x30, 0x42 // It cs; tst cs r0 r6
};
const byte kInstruction_tst_cs_r0_r7[] = {
  0x28, 0xbf, 0x38, 0x42 // It cs; tst cs r0 r7
};
const byte kInstruction_tst_cs_r1_r0[] = {
  0x28, 0xbf, 0x01, 0x42 // It cs; tst cs r1 r0
};
const byte kInstruction_tst_cs_r1_r1[] = {
  0x28, 0xbf, 0x09, 0x42 // It cs; tst cs r1 r1
};
const byte kInstruction_tst_cs_r1_r2[] = {
  0x28, 0xbf, 0x11, 0x42 // It cs; tst cs r1 r2
};
const byte kInstruction_tst_cs_r1_r3[] = {
  0x28, 0xbf, 0x19, 0x42 // It cs; tst cs r1 r3
};
const byte kInstruction_tst_cs_r1_r4[] = {
  0x28, 0xbf, 0x21, 0x42 // It cs; tst cs r1 r4
};
const byte kInstruction_tst_cs_r1_r5[] = {
  0x28, 0xbf, 0x29, 0x42 // It cs; tst cs r1 r5
};
const byte kInstruction_tst_cs_r1_r6[] = {
  0x28, 0xbf, 0x31, 0x42 // It cs; tst cs r1 r6
};
const byte kInstruction_tst_cs_r1_r7[] = {
  0x28, 0xbf, 0x39, 0x42 // It cs; tst cs r1 r7
};
const byte kInstruction_tst_cs_r2_r0[] = {
  0x28, 0xbf, 0x02, 0x42 // It cs; tst cs r2 r0
};
const byte kInstruction_tst_cs_r2_r1[] = {
  0x28, 0xbf, 0x0a, 0x42 // It cs; tst cs r2 r1
};
const byte kInstruction_tst_cs_r2_r2[] = {
  0x28, 0xbf, 0x12, 0x42 // It cs; tst cs r2 r2
};
const byte kInstruction_tst_cs_r2_r3[] = {
  0x28, 0xbf, 0x1a, 0x42 // It cs; tst cs r2 r3
};
const byte kInstruction_tst_cs_r2_r4[] = {
  0x28, 0xbf, 0x22, 0x42 // It cs; tst cs r2 r4
};
const byte kInstruction_tst_cs_r2_r5[] = {
  0x28, 0xbf, 0x2a, 0x42 // It cs; tst cs r2 r5
};
const byte kInstruction_tst_cs_r2_r6[] = {
  0x28, 0xbf, 0x32, 0x42 // It cs; tst cs r2 r6
};
const byte kInstruction_tst_cs_r2_r7[] = {
  0x28, 0xbf, 0x3a, 0x42 // It cs; tst cs r2 r7
};
const byte kInstruction_tst_cs_r3_r0[] = {
  0x28, 0xbf, 0x03, 0x42 // It cs; tst cs r3 r0
};
const byte kInstruction_tst_cs_r3_r1[] = {
  0x28, 0xbf, 0x0b, 0x42 // It cs; tst cs r3 r1
};
const byte kInstruction_tst_cs_r3_r2[] = {
  0x28, 0xbf, 0x13, 0x42 // It cs; tst cs r3 r2
};
const byte kInstruction_tst_cs_r3_r3[] = {
  0x28, 0xbf, 0x1b, 0x42 // It cs; tst cs r3 r3
};
const byte kInstruction_tst_cs_r3_r4[] = {
  0x28, 0xbf, 0x23, 0x42 // It cs; tst cs r3 r4
};
const byte kInstruction_tst_cs_r3_r5[] = {
  0x28, 0xbf, 0x2b, 0x42 // It cs; tst cs r3 r5
};
const byte kInstruction_tst_cs_r3_r6[] = {
  0x28, 0xbf, 0x33, 0x42 // It cs; tst cs r3 r6
};
const byte kInstruction_tst_cs_r3_r7[] = {
  0x28, 0xbf, 0x3b, 0x42 // It cs; tst cs r3 r7
};
const byte kInstruction_tst_cs_r4_r0[] = {
  0x28, 0xbf, 0x04, 0x42 // It cs; tst cs r4 r0
};
const byte kInstruction_tst_cs_r4_r1[] = {
  0x28, 0xbf, 0x0c, 0x42 // It cs; tst cs r4 r1
};
const byte kInstruction_tst_cs_r4_r2[] = {
  0x28, 0xbf, 0x14, 0x42 // It cs; tst cs r4 r2
};
const byte kInstruction_tst_cs_r4_r3[] = {
  0x28, 0xbf, 0x1c, 0x42 // It cs; tst cs r4 r3
};
const byte kInstruction_tst_cs_r4_r4[] = {
  0x28, 0xbf, 0x24, 0x42 // It cs; tst cs r4 r4
};
const byte kInstruction_tst_cs_r4_r5[] = {
  0x28, 0xbf, 0x2c, 0x42 // It cs; tst cs r4 r5
};
const byte kInstruction_tst_cs_r4_r6[] = {
  0x28, 0xbf, 0x34, 0x42 // It cs; tst cs r4 r6
};
const byte kInstruction_tst_cs_r4_r7[] = {
  0x28, 0xbf, 0x3c, 0x42 // It cs; tst cs r4 r7
};
const byte kInstruction_tst_cs_r5_r0[] = {
  0x28, 0xbf, 0x05, 0x42 // It cs; tst cs r5 r0
};
const byte kInstruction_tst_cs_r5_r1[] = {
  0x28, 0xbf, 0x0d, 0x42 // It cs; tst cs r5 r1
};
const byte kInstruction_tst_cs_r5_r2[] = {
  0x28, 0xbf, 0x15, 0x42 // It cs; tst cs r5 r2
};
const byte kInstruction_tst_cs_r5_r3[] = {
  0x28, 0xbf, 0x1d, 0x42 // It cs; tst cs r5 r3
};
const byte kInstruction_tst_cs_r5_r4[] = {
  0x28, 0xbf, 0x25, 0x42 // It cs; tst cs r5 r4
};
const byte kInstruction_tst_cs_r5_r5[] = {
  0x28, 0xbf, 0x2d, 0x42 // It cs; tst cs r5 r5
};
const byte kInstruction_tst_cs_r5_r6[] = {
  0x28, 0xbf, 0x35, 0x42 // It cs; tst cs r5 r6
};
const byte kInstruction_tst_cs_r5_r7[] = {
  0x28, 0xbf, 0x3d, 0x42 // It cs; tst cs r5 r7
};
const byte kInstruction_tst_cs_r6_r0[] = {
  0x28, 0xbf, 0x06, 0x42 // It cs; tst cs r6 r0
};
const byte kInstruction_tst_cs_r6_r1[] = {
  0x28, 0xbf, 0x0e, 0x42 // It cs; tst cs r6 r1
};
const byte kInstruction_tst_cs_r6_r2[] = {
  0x28, 0xbf, 0x16, 0x42 // It cs; tst cs r6 r2
};
const byte kInstruction_tst_cs_r6_r3[] = {
  0x28, 0xbf, 0x1e, 0x42 // It cs; tst cs r6 r3
};
const byte kInstruction_tst_cs_r6_r4[] = {
  0x28, 0xbf, 0x26, 0x42 // It cs; tst cs r6 r4
};
const byte kInstruction_tst_cs_r6_r5[] = {
  0x28, 0xbf, 0x2e, 0x42 // It cs; tst cs r6 r5
};
const byte kInstruction_tst_cs_r6_r6[] = {
  0x28, 0xbf, 0x36, 0x42 // It cs; tst cs r6 r6
};
const byte kInstruction_tst_cs_r6_r7[] = {
  0x28, 0xbf, 0x3e, 0x42 // It cs; tst cs r6 r7
};
const byte kInstruction_tst_cs_r7_r0[] = {
  0x28, 0xbf, 0x07, 0x42 // It cs; tst cs r7 r0
};
const byte kInstruction_tst_cs_r7_r1[] = {
  0x28, 0xbf, 0x0f, 0x42 // It cs; tst cs r7 r1
};
const byte kInstruction_tst_cs_r7_r2[] = {
  0x28, 0xbf, 0x17, 0x42 // It cs; tst cs r7 r2
};
const byte kInstruction_tst_cs_r7_r3[] = {
  0x28, 0xbf, 0x1f, 0x42 // It cs; tst cs r7 r3
};
const byte kInstruction_tst_cs_r7_r4[] = {
  0x28, 0xbf, 0x27, 0x42 // It cs; tst cs r7 r4
};
const byte kInstruction_tst_cs_r7_r5[] = {
  0x28, 0xbf, 0x2f, 0x42 // It cs; tst cs r7 r5
};
const byte kInstruction_tst_cs_r7_r6[] = {
  0x28, 0xbf, 0x37, 0x42 // It cs; tst cs r7 r6
};
const byte kInstruction_tst_cs_r7_r7[] = {
  0x28, 0xbf, 0x3f, 0x42 // It cs; tst cs r7 r7
};
const byte kInstruction_tst_cc_r0_r0[] = {
  0x38, 0xbf, 0x00, 0x42 // It cc; tst cc r0 r0
};
const byte kInstruction_tst_cc_r0_r1[] = {
  0x38, 0xbf, 0x08, 0x42 // It cc; tst cc r0 r1
};
const byte kInstruction_tst_cc_r0_r2[] = {
  0x38, 0xbf, 0x10, 0x42 // It cc; tst cc r0 r2
};
const byte kInstruction_tst_cc_r0_r3[] = {
  0x38, 0xbf, 0x18, 0x42 // It cc; tst cc r0 r3
};
const byte kInstruction_tst_cc_r0_r4[] = {
  0x38, 0xbf, 0x20, 0x42 // It cc; tst cc r0 r4
};
const byte kInstruction_tst_cc_r0_r5[] = {
  0x38, 0xbf, 0x28, 0x42 // It cc; tst cc r0 r5
};
const byte kInstruction_tst_cc_r0_r6[] = {
  0x38, 0xbf, 0x30, 0x42 // It cc; tst cc r0 r6
};
const byte kInstruction_tst_cc_r0_r7[] = {
  0x38, 0xbf, 0x38, 0x42 // It cc; tst cc r0 r7
};
const byte kInstruction_tst_cc_r1_r0[] = {
  0x38, 0xbf, 0x01, 0x42 // It cc; tst cc r1 r0
};
const byte kInstruction_tst_cc_r1_r1[] = {
  0x38, 0xbf, 0x09, 0x42 // It cc; tst cc r1 r1
};
const byte kInstruction_tst_cc_r1_r2[] = {
  0x38, 0xbf, 0x11, 0x42 // It cc; tst cc r1 r2
};
const byte kInstruction_tst_cc_r1_r3[] = {
  0x38, 0xbf, 0x19, 0x42 // It cc; tst cc r1 r3
};
const byte kInstruction_tst_cc_r1_r4[] = {
  0x38, 0xbf, 0x21, 0x42 // It cc; tst cc r1 r4
};
const byte kInstruction_tst_cc_r1_r5[] = {
  0x38, 0xbf, 0x29, 0x42 // It cc; tst cc r1 r5
};
const byte kInstruction_tst_cc_r1_r6[] = {
  0x38, 0xbf, 0x31, 0x42 // It cc; tst cc r1 r6
};
const byte kInstruction_tst_cc_r1_r7[] = {
  0x38, 0xbf, 0x39, 0x42 // It cc; tst cc r1 r7
};
const byte kInstruction_tst_cc_r2_r0[] = {
  0x38, 0xbf, 0x02, 0x42 // It cc; tst cc r2 r0
};
const byte kInstruction_tst_cc_r2_r1[] = {
  0x38, 0xbf, 0x0a, 0x42 // It cc; tst cc r2 r1
};
const byte kInstruction_tst_cc_r2_r2[] = {
  0x38, 0xbf, 0x12, 0x42 // It cc; tst cc r2 r2
};
const byte kInstruction_tst_cc_r2_r3[] = {
  0x38, 0xbf, 0x1a, 0x42 // It cc; tst cc r2 r3
};
const byte kInstruction_tst_cc_r2_r4[] = {
  0x38, 0xbf, 0x22, 0x42 // It cc; tst cc r2 r4
};
const byte kInstruction_tst_cc_r2_r5[] = {
  0x38, 0xbf, 0x2a, 0x42 // It cc; tst cc r2 r5
};
const byte kInstruction_tst_cc_r2_r6[] = {
  0x38, 0xbf, 0x32, 0x42 // It cc; tst cc r2 r6
};
const byte kInstruction_tst_cc_r2_r7[] = {
  0x38, 0xbf, 0x3a, 0x42 // It cc; tst cc r2 r7
};
const byte kInstruction_tst_cc_r3_r0[] = {
  0x38, 0xbf, 0x03, 0x42 // It cc; tst cc r3 r0
};
const byte kInstruction_tst_cc_r3_r1[] = {
  0x38, 0xbf, 0x0b, 0x42 // It cc; tst cc r3 r1
};
const byte kInstruction_tst_cc_r3_r2[] = {
  0x38, 0xbf, 0x13, 0x42 // It cc; tst cc r3 r2
};
const byte kInstruction_tst_cc_r3_r3[] = {
  0x38, 0xbf, 0x1b, 0x42 // It cc; tst cc r3 r3
};
const byte kInstruction_tst_cc_r3_r4[] = {
  0x38, 0xbf, 0x23, 0x42 // It cc; tst cc r3 r4
};
const byte kInstruction_tst_cc_r3_r5[] = {
  0x38, 0xbf, 0x2b, 0x42 // It cc; tst cc r3 r5
};
const byte kInstruction_tst_cc_r3_r6[] = {
  0x38, 0xbf, 0x33, 0x42 // It cc; tst cc r3 r6
};
const byte kInstruction_tst_cc_r3_r7[] = {
  0x38, 0xbf, 0x3b, 0x42 // It cc; tst cc r3 r7
};
const byte kInstruction_tst_cc_r4_r0[] = {
  0x38, 0xbf, 0x04, 0x42 // It cc; tst cc r4 r0
};
const byte kInstruction_tst_cc_r4_r1[] = {
  0x38, 0xbf, 0x0c, 0x42 // It cc; tst cc r4 r1
};
const byte kInstruction_tst_cc_r4_r2[] = {
  0x38, 0xbf, 0x14, 0x42 // It cc; tst cc r4 r2
};
const byte kInstruction_tst_cc_r4_r3[] = {
  0x38, 0xbf, 0x1c, 0x42 // It cc; tst cc r4 r3
};
const byte kInstruction_tst_cc_r4_r4[] = {
  0x38, 0xbf, 0x24, 0x42 // It cc; tst cc r4 r4
};
const byte kInstruction_tst_cc_r4_r5[] = {
  0x38, 0xbf, 0x2c, 0x42 // It cc; tst cc r4 r5
};
const byte kInstruction_tst_cc_r4_r6[] = {
  0x38, 0xbf, 0x34, 0x42 // It cc; tst cc r4 r6
};
const byte kInstruction_tst_cc_r4_r7[] = {
  0x38, 0xbf, 0x3c, 0x42 // It cc; tst cc r4 r7
};
const byte kInstruction_tst_cc_r5_r0[] = {
  0x38, 0xbf, 0x05, 0x42 // It cc; tst cc r5 r0
};
const byte kInstruction_tst_cc_r5_r1[] = {
  0x38, 0xbf, 0x0d, 0x42 // It cc; tst cc r5 r1
};
const byte kInstruction_tst_cc_r5_r2[] = {
  0x38, 0xbf, 0x15, 0x42 // It cc; tst cc r5 r2
};
const byte kInstruction_tst_cc_r5_r3[] = {
  0x38, 0xbf, 0x1d, 0x42 // It cc; tst cc r5 r3
};
const byte kInstruction_tst_cc_r5_r4[] = {
  0x38, 0xbf, 0x25, 0x42 // It cc; tst cc r5 r4
};
const byte kInstruction_tst_cc_r5_r5[] = {
  0x38, 0xbf, 0x2d, 0x42 // It cc; tst cc r5 r5
};
const byte kInstruction_tst_cc_r5_r6[] = {
  0x38, 0xbf, 0x35, 0x42 // It cc; tst cc r5 r6
};
const byte kInstruction_tst_cc_r5_r7[] = {
  0x38, 0xbf, 0x3d, 0x42 // It cc; tst cc r5 r7
};
const byte kInstruction_tst_cc_r6_r0[] = {
  0x38, 0xbf, 0x06, 0x42 // It cc; tst cc r6 r0
};
const byte kInstruction_tst_cc_r6_r1[] = {
  0x38, 0xbf, 0x0e, 0x42 // It cc; tst cc r6 r1
};
const byte kInstruction_tst_cc_r6_r2[] = {
  0x38, 0xbf, 0x16, 0x42 // It cc; tst cc r6 r2
};
const byte kInstruction_tst_cc_r6_r3[] = {
  0x38, 0xbf, 0x1e, 0x42 // It cc; tst cc r6 r3
};
const byte kInstruction_tst_cc_r6_r4[] = {
  0x38, 0xbf, 0x26, 0x42 // It cc; tst cc r6 r4
};
const byte kInstruction_tst_cc_r6_r5[] = {
  0x38, 0xbf, 0x2e, 0x42 // It cc; tst cc r6 r5
};
const byte kInstruction_tst_cc_r6_r6[] = {
  0x38, 0xbf, 0x36, 0x42 // It cc; tst cc r6 r6
};
const byte kInstruction_tst_cc_r6_r7[] = {
  0x38, 0xbf, 0x3e, 0x42 // It cc; tst cc r6 r7
};
const byte kInstruction_tst_cc_r7_r0[] = {
  0x38, 0xbf, 0x07, 0x42 // It cc; tst cc r7 r0
};
const byte kInstruction_tst_cc_r7_r1[] = {
  0x38, 0xbf, 0x0f, 0x42 // It cc; tst cc r7 r1
};
const byte kInstruction_tst_cc_r7_r2[] = {
  0x38, 0xbf, 0x17, 0x42 // It cc; tst cc r7 r2
};
const byte kInstruction_tst_cc_r7_r3[] = {
  0x38, 0xbf, 0x1f, 0x42 // It cc; tst cc r7 r3
};
const byte kInstruction_tst_cc_r7_r4[] = {
  0x38, 0xbf, 0x27, 0x42 // It cc; tst cc r7 r4
};
const byte kInstruction_tst_cc_r7_r5[] = {
  0x38, 0xbf, 0x2f, 0x42 // It cc; tst cc r7 r5
};
const byte kInstruction_tst_cc_r7_r6[] = {
  0x38, 0xbf, 0x37, 0x42 // It cc; tst cc r7 r6
};
const byte kInstruction_tst_cc_r7_r7[] = {
  0x38, 0xbf, 0x3f, 0x42 // It cc; tst cc r7 r7
};
const byte kInstruction_tst_mi_r0_r0[] = {
  0x48, 0xbf, 0x00, 0x42 // It mi; tst mi r0 r0
};
const byte kInstruction_tst_mi_r0_r1[] = {
  0x48, 0xbf, 0x08, 0x42 // It mi; tst mi r0 r1
};
const byte kInstruction_tst_mi_r0_r2[] = {
  0x48, 0xbf, 0x10, 0x42 // It mi; tst mi r0 r2
};
const byte kInstruction_tst_mi_r0_r3[] = {
  0x48, 0xbf, 0x18, 0x42 // It mi; tst mi r0 r3
};
const byte kInstruction_tst_mi_r0_r4[] = {
  0x48, 0xbf, 0x20, 0x42 // It mi; tst mi r0 r4
};
const byte kInstruction_tst_mi_r0_r5[] = {
  0x48, 0xbf, 0x28, 0x42 // It mi; tst mi r0 r5
};
const byte kInstruction_tst_mi_r0_r6[] = {
  0x48, 0xbf, 0x30, 0x42 // It mi; tst mi r0 r6
};
const byte kInstruction_tst_mi_r0_r7[] = {
  0x48, 0xbf, 0x38, 0x42 // It mi; tst mi r0 r7
};
const byte kInstruction_tst_mi_r1_r0[] = {
  0x48, 0xbf, 0x01, 0x42 // It mi; tst mi r1 r0
};
const byte kInstruction_tst_mi_r1_r1[] = {
  0x48, 0xbf, 0x09, 0x42 // It mi; tst mi r1 r1
};
const byte kInstruction_tst_mi_r1_r2[] = {
  0x48, 0xbf, 0x11, 0x42 // It mi; tst mi r1 r2
};
const byte kInstruction_tst_mi_r1_r3[] = {
  0x48, 0xbf, 0x19, 0x42 // It mi; tst mi r1 r3
};
const byte kInstruction_tst_mi_r1_r4[] = {
  0x48, 0xbf, 0x21, 0x42 // It mi; tst mi r1 r4
};
const byte kInstruction_tst_mi_r1_r5[] = {
  0x48, 0xbf, 0x29, 0x42 // It mi; tst mi r1 r5
};
const byte kInstruction_tst_mi_r1_r6[] = {
  0x48, 0xbf, 0x31, 0x42 // It mi; tst mi r1 r6
};
const byte kInstruction_tst_mi_r1_r7[] = {
  0x48, 0xbf, 0x39, 0x42 // It mi; tst mi r1 r7
};
const byte kInstruction_tst_mi_r2_r0[] = {
  0x48, 0xbf, 0x02, 0x42 // It mi; tst mi r2 r0
};
const byte kInstruction_tst_mi_r2_r1[] = {
  0x48, 0xbf, 0x0a, 0x42 // It mi; tst mi r2 r1
};
const byte kInstruction_tst_mi_r2_r2[] = {
  0x48, 0xbf, 0x12, 0x42 // It mi; tst mi r2 r2
};
const byte kInstruction_tst_mi_r2_r3[] = {
  0x48, 0xbf, 0x1a, 0x42 // It mi; tst mi r2 r3
};
const byte kInstruction_tst_mi_r2_r4[] = {
  0x48, 0xbf, 0x22, 0x42 // It mi; tst mi r2 r4
};
const byte kInstruction_tst_mi_r2_r5[] = {
  0x48, 0xbf, 0x2a, 0x42 // It mi; tst mi r2 r5
};
const byte kInstruction_tst_mi_r2_r6[] = {
  0x48, 0xbf, 0x32, 0x42 // It mi; tst mi r2 r6
};
const byte kInstruction_tst_mi_r2_r7[] = {
  0x48, 0xbf, 0x3a, 0x42 // It mi; tst mi r2 r7
};
const byte kInstruction_tst_mi_r3_r0[] = {
  0x48, 0xbf, 0x03, 0x42 // It mi; tst mi r3 r0
};
const byte kInstruction_tst_mi_r3_r1[] = {
  0x48, 0xbf, 0x0b, 0x42 // It mi; tst mi r3 r1
};
const byte kInstruction_tst_mi_r3_r2[] = {
  0x48, 0xbf, 0x13, 0x42 // It mi; tst mi r3 r2
};
const byte kInstruction_tst_mi_r3_r3[] = {
  0x48, 0xbf, 0x1b, 0x42 // It mi; tst mi r3 r3
};
const byte kInstruction_tst_mi_r3_r4[] = {
  0x48, 0xbf, 0x23, 0x42 // It mi; tst mi r3 r4
};
const byte kInstruction_tst_mi_r3_r5[] = {
  0x48, 0xbf, 0x2b, 0x42 // It mi; tst mi r3 r5
};
const byte kInstruction_tst_mi_r3_r6[] = {
  0x48, 0xbf, 0x33, 0x42 // It mi; tst mi r3 r6
};
const byte kInstruction_tst_mi_r3_r7[] = {
  0x48, 0xbf, 0x3b, 0x42 // It mi; tst mi r3 r7
};
const byte kInstruction_tst_mi_r4_r0[] = {
  0x48, 0xbf, 0x04, 0x42 // It mi; tst mi r4 r0
};
const byte kInstruction_tst_mi_r4_r1[] = {
  0x48, 0xbf, 0x0c, 0x42 // It mi; tst mi r4 r1
};
const byte kInstruction_tst_mi_r4_r2[] = {
  0x48, 0xbf, 0x14, 0x42 // It mi; tst mi r4 r2
};
const byte kInstruction_tst_mi_r4_r3[] = {
  0x48, 0xbf, 0x1c, 0x42 // It mi; tst mi r4 r3
};
const byte kInstruction_tst_mi_r4_r4[] = {
  0x48, 0xbf, 0x24, 0x42 // It mi; tst mi r4 r4
};
const byte kInstruction_tst_mi_r4_r5[] = {
  0x48, 0xbf, 0x2c, 0x42 // It mi; tst mi r4 r5
};
const byte kInstruction_tst_mi_r4_r6[] = {
  0x48, 0xbf, 0x34, 0x42 // It mi; tst mi r4 r6
};
const byte kInstruction_tst_mi_r4_r7[] = {
  0x48, 0xbf, 0x3c, 0x42 // It mi; tst mi r4 r7
};
const byte kInstruction_tst_mi_r5_r0[] = {
  0x48, 0xbf, 0x05, 0x42 // It mi; tst mi r5 r0
};
const byte kInstruction_tst_mi_r5_r1[] = {
  0x48, 0xbf, 0x0d, 0x42 // It mi; tst mi r5 r1
};
const byte kInstruction_tst_mi_r5_r2[] = {
  0x48, 0xbf, 0x15, 0x42 // It mi; tst mi r5 r2
};
const byte kInstruction_tst_mi_r5_r3[] = {
  0x48, 0xbf, 0x1d, 0x42 // It mi; tst mi r5 r3
};
const byte kInstruction_tst_mi_r5_r4[] = {
  0x48, 0xbf, 0x25, 0x42 // It mi; tst mi r5 r4
};
const byte kInstruction_tst_mi_r5_r5[] = {
  0x48, 0xbf, 0x2d, 0x42 // It mi; tst mi r5 r5
};
const byte kInstruction_tst_mi_r5_r6[] = {
  0x48, 0xbf, 0x35, 0x42 // It mi; tst mi r5 r6
};
const byte kInstruction_tst_mi_r5_r7[] = {
  0x48, 0xbf, 0x3d, 0x42 // It mi; tst mi r5 r7
};
const byte kInstruction_tst_mi_r6_r0[] = {
  0x48, 0xbf, 0x06, 0x42 // It mi; tst mi r6 r0
};
const byte kInstruction_tst_mi_r6_r1[] = {
  0x48, 0xbf, 0x0e, 0x42 // It mi; tst mi r6 r1
};
const byte kInstruction_tst_mi_r6_r2[] = {
  0x48, 0xbf, 0x16, 0x42 // It mi; tst mi r6 r2
};
const byte kInstruction_tst_mi_r6_r3[] = {
  0x48, 0xbf, 0x1e, 0x42 // It mi; tst mi r6 r3
};
const byte kInstruction_tst_mi_r6_r4[] = {
  0x48, 0xbf, 0x26, 0x42 // It mi; tst mi r6 r4
};
const byte kInstruction_tst_mi_r6_r5[] = {
  0x48, 0xbf, 0x2e, 0x42 // It mi; tst mi r6 r5
};
const byte kInstruction_tst_mi_r6_r6[] = {
  0x48, 0xbf, 0x36, 0x42 // It mi; tst mi r6 r6
};
const byte kInstruction_tst_mi_r6_r7[] = {
  0x48, 0xbf, 0x3e, 0x42 // It mi; tst mi r6 r7
};
const byte kInstruction_tst_mi_r7_r0[] = {
  0x48, 0xbf, 0x07, 0x42 // It mi; tst mi r7 r0
};
const byte kInstruction_tst_mi_r7_r1[] = {
  0x48, 0xbf, 0x0f, 0x42 // It mi; tst mi r7 r1
};
const byte kInstruction_tst_mi_r7_r2[] = {
  0x48, 0xbf, 0x17, 0x42 // It mi; tst mi r7 r2
};
const byte kInstruction_tst_mi_r7_r3[] = {
  0x48, 0xbf, 0x1f, 0x42 // It mi; tst mi r7 r3
};
const byte kInstruction_tst_mi_r7_r4[] = {
  0x48, 0xbf, 0x27, 0x42 // It mi; tst mi r7 r4
};
const byte kInstruction_tst_mi_r7_r5[] = {
  0x48, 0xbf, 0x2f, 0x42 // It mi; tst mi r7 r5
};
const byte kInstruction_tst_mi_r7_r6[] = {
  0x48, 0xbf, 0x37, 0x42 // It mi; tst mi r7 r6
};
const byte kInstruction_tst_mi_r7_r7[] = {
  0x48, 0xbf, 0x3f, 0x42 // It mi; tst mi r7 r7
};
const byte kInstruction_tst_pl_r0_r0[] = {
  0x58, 0xbf, 0x00, 0x42 // It pl; tst pl r0 r0
};
const byte kInstruction_tst_pl_r0_r1[] = {
  0x58, 0xbf, 0x08, 0x42 // It pl; tst pl r0 r1
};
const byte kInstruction_tst_pl_r0_r2[] = {
  0x58, 0xbf, 0x10, 0x42 // It pl; tst pl r0 r2
};
const byte kInstruction_tst_pl_r0_r3[] = {
  0x58, 0xbf, 0x18, 0x42 // It pl; tst pl r0 r3
};
const byte kInstruction_tst_pl_r0_r4[] = {
  0x58, 0xbf, 0x20, 0x42 // It pl; tst pl r0 r4
};
const byte kInstruction_tst_pl_r0_r5[] = {
  0x58, 0xbf, 0x28, 0x42 // It pl; tst pl r0 r5
};
const byte kInstruction_tst_pl_r0_r6[] = {
  0x58, 0xbf, 0x30, 0x42 // It pl; tst pl r0 r6
};
const byte kInstruction_tst_pl_r0_r7[] = {
  0x58, 0xbf, 0x38, 0x42 // It pl; tst pl r0 r7
};
const byte kInstruction_tst_pl_r1_r0[] = {
  0x58, 0xbf, 0x01, 0x42 // It pl; tst pl r1 r0
};
const byte kInstruction_tst_pl_r1_r1[] = {
  0x58, 0xbf, 0x09, 0x42 // It pl; tst pl r1 r1
};
const byte kInstruction_tst_pl_r1_r2[] = {
  0x58, 0xbf, 0x11, 0x42 // It pl; tst pl r1 r2
};
const byte kInstruction_tst_pl_r1_r3[] = {
  0x58, 0xbf, 0x19, 0x42 // It pl; tst pl r1 r3
};
const byte kInstruction_tst_pl_r1_r4[] = {
  0x58, 0xbf, 0x21, 0x42 // It pl; tst pl r1 r4
};
const byte kInstruction_tst_pl_r1_r5[] = {
  0x58, 0xbf, 0x29, 0x42 // It pl; tst pl r1 r5
};
const byte kInstruction_tst_pl_r1_r6[] = {
  0x58, 0xbf, 0x31, 0x42 // It pl; tst pl r1 r6
};
const byte kInstruction_tst_pl_r1_r7[] = {
  0x58, 0xbf, 0x39, 0x42 // It pl; tst pl r1 r7
};
const byte kInstruction_tst_pl_r2_r0[] = {
  0x58, 0xbf, 0x02, 0x42 // It pl; tst pl r2 r0
};
const byte kInstruction_tst_pl_r2_r1[] = {
  0x58, 0xbf, 0x0a, 0x42 // It pl; tst pl r2 r1
};
const byte kInstruction_tst_pl_r2_r2[] = {
  0x58, 0xbf, 0x12, 0x42 // It pl; tst pl r2 r2
};
const byte kInstruction_tst_pl_r2_r3[] = {
  0x58, 0xbf, 0x1a, 0x42 // It pl; tst pl r2 r3
};
const byte kInstruction_tst_pl_r2_r4[] = {
  0x58, 0xbf, 0x22, 0x42 // It pl; tst pl r2 r4
};
const byte kInstruction_tst_pl_r2_r5[] = {
  0x58, 0xbf, 0x2a, 0x42 // It pl; tst pl r2 r5
};
const byte kInstruction_tst_pl_r2_r6[] = {
  0x58, 0xbf, 0x32, 0x42 // It pl; tst pl r2 r6
};
const byte kInstruction_tst_pl_r2_r7[] = {
  0x58, 0xbf, 0x3a, 0x42 // It pl; tst pl r2 r7
};
const byte kInstruction_tst_pl_r3_r0[] = {
  0x58, 0xbf, 0x03, 0x42 // It pl; tst pl r3 r0
};
const byte kInstruction_tst_pl_r3_r1[] = {
  0x58, 0xbf, 0x0b, 0x42 // It pl; tst pl r3 r1
};
const byte kInstruction_tst_pl_r3_r2[] = {
  0x58, 0xbf, 0x13, 0x42 // It pl; tst pl r3 r2
};
const byte kInstruction_tst_pl_r3_r3[] = {
  0x58, 0xbf, 0x1b, 0x42 // It pl; tst pl r3 r3
};
const byte kInstruction_tst_pl_r3_r4[] = {
  0x58, 0xbf, 0x23, 0x42 // It pl; tst pl r3 r4
};
const byte kInstruction_tst_pl_r3_r5[] = {
  0x58, 0xbf, 0x2b, 0x42 // It pl; tst pl r3 r5
};
const byte kInstruction_tst_pl_r3_r6[] = {
  0x58, 0xbf, 0x33, 0x42 // It pl; tst pl r3 r6
};
const byte kInstruction_tst_pl_r3_r7[] = {
  0x58, 0xbf, 0x3b, 0x42 // It pl; tst pl r3 r7
};
const byte kInstruction_tst_pl_r4_r0[] = {
  0x58, 0xbf, 0x04, 0x42 // It pl; tst pl r4 r0
};
const byte kInstruction_tst_pl_r4_r1[] = {
  0x58, 0xbf, 0x0c, 0x42 // It pl; tst pl r4 r1
};
const byte kInstruction_tst_pl_r4_r2[] = {
  0x58, 0xbf, 0x14, 0x42 // It pl; tst pl r4 r2
};
const byte kInstruction_tst_pl_r4_r3[] = {
  0x58, 0xbf, 0x1c, 0x42 // It pl; tst pl r4 r3
};
const byte kInstruction_tst_pl_r4_r4[] = {
  0x58, 0xbf, 0x24, 0x42 // It pl; tst pl r4 r4
};
const byte kInstruction_tst_pl_r4_r5[] = {
  0x58, 0xbf, 0x2c, 0x42 // It pl; tst pl r4 r5
};
const byte kInstruction_tst_pl_r4_r6[] = {
  0x58, 0xbf, 0x34, 0x42 // It pl; tst pl r4 r6
};
const byte kInstruction_tst_pl_r4_r7[] = {
  0x58, 0xbf, 0x3c, 0x42 // It pl; tst pl r4 r7
};
const byte kInstruction_tst_pl_r5_r0[] = {
  0x58, 0xbf, 0x05, 0x42 // It pl; tst pl r5 r0
};
const byte kInstruction_tst_pl_r5_r1[] = {
  0x58, 0xbf, 0x0d, 0x42 // It pl; tst pl r5 r1
};
const byte kInstruction_tst_pl_r5_r2[] = {
  0x58, 0xbf, 0x15, 0x42 // It pl; tst pl r5 r2
};
const byte kInstruction_tst_pl_r5_r3[] = {
  0x58, 0xbf, 0x1d, 0x42 // It pl; tst pl r5 r3
};
const byte kInstruction_tst_pl_r5_r4[] = {
  0x58, 0xbf, 0x25, 0x42 // It pl; tst pl r5 r4
};
const byte kInstruction_tst_pl_r5_r5[] = {
  0x58, 0xbf, 0x2d, 0x42 // It pl; tst pl r5 r5
};
const byte kInstruction_tst_pl_r5_r6[] = {
  0x58, 0xbf, 0x35, 0x42 // It pl; tst pl r5 r6
};
const byte kInstruction_tst_pl_r5_r7[] = {
  0x58, 0xbf, 0x3d, 0x42 // It pl; tst pl r5 r7
};
const byte kInstruction_tst_pl_r6_r0[] = {
  0x58, 0xbf, 0x06, 0x42 // It pl; tst pl r6 r0
};
const byte kInstruction_tst_pl_r6_r1[] = {
  0x58, 0xbf, 0x0e, 0x42 // It pl; tst pl r6 r1
};
const byte kInstruction_tst_pl_r6_r2[] = {
  0x58, 0xbf, 0x16, 0x42 // It pl; tst pl r6 r2
};
const byte kInstruction_tst_pl_r6_r3[] = {
  0x58, 0xbf, 0x1e, 0x42 // It pl; tst pl r6 r3
};
const byte kInstruction_tst_pl_r6_r4[] = {
  0x58, 0xbf, 0x26, 0x42 // It pl; tst pl r6 r4
};
const byte kInstruction_tst_pl_r6_r5[] = {
  0x58, 0xbf, 0x2e, 0x42 // It pl; tst pl r6 r5
};
const byte kInstruction_tst_pl_r6_r6[] = {
  0x58, 0xbf, 0x36, 0x42 // It pl; tst pl r6 r6
};
const byte kInstruction_tst_pl_r6_r7[] = {
  0x58, 0xbf, 0x3e, 0x42 // It pl; tst pl r6 r7
};
const byte kInstruction_tst_pl_r7_r0[] = {
  0x58, 0xbf, 0x07, 0x42 // It pl; tst pl r7 r0
};
const byte kInstruction_tst_pl_r7_r1[] = {
  0x58, 0xbf, 0x0f, 0x42 // It pl; tst pl r7 r1
};
const byte kInstruction_tst_pl_r7_r2[] = {
  0x58, 0xbf, 0x17, 0x42 // It pl; tst pl r7 r2
};
const byte kInstruction_tst_pl_r7_r3[] = {
  0x58, 0xbf, 0x1f, 0x42 // It pl; tst pl r7 r3
};
const byte kInstruction_tst_pl_r7_r4[] = {
  0x58, 0xbf, 0x27, 0x42 // It pl; tst pl r7 r4
};
const byte kInstruction_tst_pl_r7_r5[] = {
  0x58, 0xbf, 0x2f, 0x42 // It pl; tst pl r7 r5
};
const byte kInstruction_tst_pl_r7_r6[] = {
  0x58, 0xbf, 0x37, 0x42 // It pl; tst pl r7 r6
};
const byte kInstruction_tst_pl_r7_r7[] = {
  0x58, 0xbf, 0x3f, 0x42 // It pl; tst pl r7 r7
};
const byte kInstruction_tst_vs_r0_r0[] = {
  0x68, 0xbf, 0x00, 0x42 // It vs; tst vs r0 r0
};
const byte kInstruction_tst_vs_r0_r1[] = {
  0x68, 0xbf, 0x08, 0x42 // It vs; tst vs r0 r1
};
const byte kInstruction_tst_vs_r0_r2[] = {
  0x68, 0xbf, 0x10, 0x42 // It vs; tst vs r0 r2
};
const byte kInstruction_tst_vs_r0_r3[] = {
  0x68, 0xbf, 0x18, 0x42 // It vs; tst vs r0 r3
};
const byte kInstruction_tst_vs_r0_r4[] = {
  0x68, 0xbf, 0x20, 0x42 // It vs; tst vs r0 r4
};
const byte kInstruction_tst_vs_r0_r5[] = {
  0x68, 0xbf, 0x28, 0x42 // It vs; tst vs r0 r5
};
const byte kInstruction_tst_vs_r0_r6[] = {
  0x68, 0xbf, 0x30, 0x42 // It vs; tst vs r0 r6
};
const byte kInstruction_tst_vs_r0_r7[] = {
  0x68, 0xbf, 0x38, 0x42 // It vs; tst vs r0 r7
};
const byte kInstruction_tst_vs_r1_r0[] = {
  0x68, 0xbf, 0x01, 0x42 // It vs; tst vs r1 r0
};
const byte kInstruction_tst_vs_r1_r1[] = {
  0x68, 0xbf, 0x09, 0x42 // It vs; tst vs r1 r1
};
const byte kInstruction_tst_vs_r1_r2[] = {
  0x68, 0xbf, 0x11, 0x42 // It vs; tst vs r1 r2
};
const byte kInstruction_tst_vs_r1_r3[] = {
  0x68, 0xbf, 0x19, 0x42 // It vs; tst vs r1 r3
};
const byte kInstruction_tst_vs_r1_r4[] = {
  0x68, 0xbf, 0x21, 0x42 // It vs; tst vs r1 r4
};
const byte kInstruction_tst_vs_r1_r5[] = {
  0x68, 0xbf, 0x29, 0x42 // It vs; tst vs r1 r5
};
const byte kInstruction_tst_vs_r1_r6[] = {
  0x68, 0xbf, 0x31, 0x42 // It vs; tst vs r1 r6
};
const byte kInstruction_tst_vs_r1_r7[] = {
  0x68, 0xbf, 0x39, 0x42 // It vs; tst vs r1 r7
};
const byte kInstruction_tst_vs_r2_r0[] = {
  0x68, 0xbf, 0x02, 0x42 // It vs; tst vs r2 r0
};
const byte kInstruction_tst_vs_r2_r1[] = {
  0x68, 0xbf, 0x0a, 0x42 // It vs; tst vs r2 r1
};
const byte kInstruction_tst_vs_r2_r2[] = {
  0x68, 0xbf, 0x12, 0x42 // It vs; tst vs r2 r2
};
const byte kInstruction_tst_vs_r2_r3[] = {
  0x68, 0xbf, 0x1a, 0x42 // It vs; tst vs r2 r3
};
const byte kInstruction_tst_vs_r2_r4[] = {
  0x68, 0xbf, 0x22, 0x42 // It vs; tst vs r2 r4
};
const byte kInstruction_tst_vs_r2_r5[] = {
  0x68, 0xbf, 0x2a, 0x42 // It vs; tst vs r2 r5
};
const byte kInstruction_tst_vs_r2_r6[] = {
  0x68, 0xbf, 0x32, 0x42 // It vs; tst vs r2 r6
};
const byte kInstruction_tst_vs_r2_r7[] = {
  0x68, 0xbf, 0x3a, 0x42 // It vs; tst vs r2 r7
};
const byte kInstruction_tst_vs_r3_r0[] = {
  0x68, 0xbf, 0x03, 0x42 // It vs; tst vs r3 r0
};
const byte kInstruction_tst_vs_r3_r1[] = {
  0x68, 0xbf, 0x0b, 0x42 // It vs; tst vs r3 r1
};
const byte kInstruction_tst_vs_r3_r2[] = {
  0x68, 0xbf, 0x13, 0x42 // It vs; tst vs r3 r2
};
const byte kInstruction_tst_vs_r3_r3[] = {
  0x68, 0xbf, 0x1b, 0x42 // It vs; tst vs r3 r3
};
const byte kInstruction_tst_vs_r3_r4[] = {
  0x68, 0xbf, 0x23, 0x42 // It vs; tst vs r3 r4
};
const byte kInstruction_tst_vs_r3_r5[] = {
  0x68, 0xbf, 0x2b, 0x42 // It vs; tst vs r3 r5
};
const byte kInstruction_tst_vs_r3_r6[] = {
  0x68, 0xbf, 0x33, 0x42 // It vs; tst vs r3 r6
};
const byte kInstruction_tst_vs_r3_r7[] = {
  0x68, 0xbf, 0x3b, 0x42 // It vs; tst vs r3 r7
};
const byte kInstruction_tst_vs_r4_r0[] = {
  0x68, 0xbf, 0x04, 0x42 // It vs; tst vs r4 r0
};
const byte kInstruction_tst_vs_r4_r1[] = {
  0x68, 0xbf, 0x0c, 0x42 // It vs; tst vs r4 r1
};
const byte kInstruction_tst_vs_r4_r2[] = {
  0x68, 0xbf, 0x14, 0x42 // It vs; tst vs r4 r2
};
const byte kInstruction_tst_vs_r4_r3[] = {
  0x68, 0xbf, 0x1c, 0x42 // It vs; tst vs r4 r3
};
const byte kInstruction_tst_vs_r4_r4[] = {
  0x68, 0xbf, 0x24, 0x42 // It vs; tst vs r4 r4
};
const byte kInstruction_tst_vs_r4_r5[] = {
  0x68, 0xbf, 0x2c, 0x42 // It vs; tst vs r4 r5
};
const byte kInstruction_tst_vs_r4_r6[] = {
  0x68, 0xbf, 0x34, 0x42 // It vs; tst vs r4 r6
};
const byte kInstruction_tst_vs_r4_r7[] = {
  0x68, 0xbf, 0x3c, 0x42 // It vs; tst vs r4 r7
};
const byte kInstruction_tst_vs_r5_r0[] = {
  0x68, 0xbf, 0x05, 0x42 // It vs; tst vs r5 r0
};
const byte kInstruction_tst_vs_r5_r1[] = {
  0x68, 0xbf, 0x0d, 0x42 // It vs; tst vs r5 r1
};
const byte kInstruction_tst_vs_r5_r2[] = {
  0x68, 0xbf, 0x15, 0x42 // It vs; tst vs r5 r2
};
const byte kInstruction_tst_vs_r5_r3[] = {
  0x68, 0xbf, 0x1d, 0x42 // It vs; tst vs r5 r3
};
const byte kInstruction_tst_vs_r5_r4[] = {
  0x68, 0xbf, 0x25, 0x42 // It vs; tst vs r5 r4
};
const byte kInstruction_tst_vs_r5_r5[] = {
  0x68, 0xbf, 0x2d, 0x42 // It vs; tst vs r5 r5
};
const byte kInstruction_tst_vs_r5_r6[] = {
  0x68, 0xbf, 0x35, 0x42 // It vs; tst vs r5 r6
};
const byte kInstruction_tst_vs_r5_r7[] = {
  0x68, 0xbf, 0x3d, 0x42 // It vs; tst vs r5 r7
};
const byte kInstruction_tst_vs_r6_r0[] = {
  0x68, 0xbf, 0x06, 0x42 // It vs; tst vs r6 r0
};
const byte kInstruction_tst_vs_r6_r1[] = {
  0x68, 0xbf, 0x0e, 0x42 // It vs; tst vs r6 r1
};
const byte kInstruction_tst_vs_r6_r2[] = {
  0x68, 0xbf, 0x16, 0x42 // It vs; tst vs r6 r2
};
const byte kInstruction_tst_vs_r6_r3[] = {
  0x68, 0xbf, 0x1e, 0x42 // It vs; tst vs r6 r3
};
const byte kInstruction_tst_vs_r6_r4[] = {
  0x68, 0xbf, 0x26, 0x42 // It vs; tst vs r6 r4
};
const byte kInstruction_tst_vs_r6_r5[] = {
  0x68, 0xbf, 0x2e, 0x42 // It vs; tst vs r6 r5
};
const byte kInstruction_tst_vs_r6_r6[] = {
  0x68, 0xbf, 0x36, 0x42 // It vs; tst vs r6 r6
};
const byte kInstruction_tst_vs_r6_r7[] = {
  0x68, 0xbf, 0x3e, 0x42 // It vs; tst vs r6 r7
};
const byte kInstruction_tst_vs_r7_r0[] = {
  0x68, 0xbf, 0x07, 0x42 // It vs; tst vs r7 r0
};
const byte kInstruction_tst_vs_r7_r1[] = {
  0x68, 0xbf, 0x0f, 0x42 // It vs; tst vs r7 r1
};
const byte kInstruction_tst_vs_r7_r2[] = {
  0x68, 0xbf, 0x17, 0x42 // It vs; tst vs r7 r2
};
const byte kInstruction_tst_vs_r7_r3[] = {
  0x68, 0xbf, 0x1f, 0x42 // It vs; tst vs r7 r3
};
const byte kInstruction_tst_vs_r7_r4[] = {
  0x68, 0xbf, 0x27, 0x42 // It vs; tst vs r7 r4
};
const byte kInstruction_tst_vs_r7_r5[] = {
  0x68, 0xbf, 0x2f, 0x42 // It vs; tst vs r7 r5
};
const byte kInstruction_tst_vs_r7_r6[] = {
  0x68, 0xbf, 0x37, 0x42 // It vs; tst vs r7 r6
};
const byte kInstruction_tst_vs_r7_r7[] = {
  0x68, 0xbf, 0x3f, 0x42 // It vs; tst vs r7 r7
};
const byte kInstruction_tst_vc_r0_r0[] = {
  0x78, 0xbf, 0x00, 0x42 // It vc; tst vc r0 r0
};
const byte kInstruction_tst_vc_r0_r1[] = {
  0x78, 0xbf, 0x08, 0x42 // It vc; tst vc r0 r1
};
const byte kInstruction_tst_vc_r0_r2[] = {
  0x78, 0xbf, 0x10, 0x42 // It vc; tst vc r0 r2
};
const byte kInstruction_tst_vc_r0_r3[] = {
  0x78, 0xbf, 0x18, 0x42 // It vc; tst vc r0 r3
};
const byte kInstruction_tst_vc_r0_r4[] = {
  0x78, 0xbf, 0x20, 0x42 // It vc; tst vc r0 r4
};
const byte kInstruction_tst_vc_r0_r5[] = {
  0x78, 0xbf, 0x28, 0x42 // It vc; tst vc r0 r5
};
const byte kInstruction_tst_vc_r0_r6[] = {
  0x78, 0xbf, 0x30, 0x42 // It vc; tst vc r0 r6
};
const byte kInstruction_tst_vc_r0_r7[] = {
  0x78, 0xbf, 0x38, 0x42 // It vc; tst vc r0 r7
};
const byte kInstruction_tst_vc_r1_r0[] = {
  0x78, 0xbf, 0x01, 0x42 // It vc; tst vc r1 r0
};
const byte kInstruction_tst_vc_r1_r1[] = {
  0x78, 0xbf, 0x09, 0x42 // It vc; tst vc r1 r1
};
const byte kInstruction_tst_vc_r1_r2[] = {
  0x78, 0xbf, 0x11, 0x42 // It vc; tst vc r1 r2
};
const byte kInstruction_tst_vc_r1_r3[] = {
  0x78, 0xbf, 0x19, 0x42 // It vc; tst vc r1 r3
};
const byte kInstruction_tst_vc_r1_r4[] = {
  0x78, 0xbf, 0x21, 0x42 // It vc; tst vc r1 r4
};
const byte kInstruction_tst_vc_r1_r5[] = {
  0x78, 0xbf, 0x29, 0x42 // It vc; tst vc r1 r5
};
const byte kInstruction_tst_vc_r1_r6[] = {
  0x78, 0xbf, 0x31, 0x42 // It vc; tst vc r1 r6
};
const byte kInstruction_tst_vc_r1_r7[] = {
  0x78, 0xbf, 0x39, 0x42 // It vc; tst vc r1 r7
};
const byte kInstruction_tst_vc_r2_r0[] = {
  0x78, 0xbf, 0x02, 0x42 // It vc; tst vc r2 r0
};
const byte kInstruction_tst_vc_r2_r1[] = {
  0x78, 0xbf, 0x0a, 0x42 // It vc; tst vc r2 r1
};
const byte kInstruction_tst_vc_r2_r2[] = {
  0x78, 0xbf, 0x12, 0x42 // It vc; tst vc r2 r2
};
const byte kInstruction_tst_vc_r2_r3[] = {
  0x78, 0xbf, 0x1a, 0x42 // It vc; tst vc r2 r3
};
const byte kInstruction_tst_vc_r2_r4[] = {
  0x78, 0xbf, 0x22, 0x42 // It vc; tst vc r2 r4
};
const byte kInstruction_tst_vc_r2_r5[] = {
  0x78, 0xbf, 0x2a, 0x42 // It vc; tst vc r2 r5
};
const byte kInstruction_tst_vc_r2_r6[] = {
  0x78, 0xbf, 0x32, 0x42 // It vc; tst vc r2 r6
};
const byte kInstruction_tst_vc_r2_r7[] = {
  0x78, 0xbf, 0x3a, 0x42 // It vc; tst vc r2 r7
};
const byte kInstruction_tst_vc_r3_r0[] = {
  0x78, 0xbf, 0x03, 0x42 // It vc; tst vc r3 r0
};
const byte kInstruction_tst_vc_r3_r1[] = {
  0x78, 0xbf, 0x0b, 0x42 // It vc; tst vc r3 r1
};
const byte kInstruction_tst_vc_r3_r2[] = {
  0x78, 0xbf, 0x13, 0x42 // It vc; tst vc r3 r2
};
const byte kInstruction_tst_vc_r3_r3[] = {
  0x78, 0xbf, 0x1b, 0x42 // It vc; tst vc r3 r3
};
const byte kInstruction_tst_vc_r3_r4[] = {
  0x78, 0xbf, 0x23, 0x42 // It vc; tst vc r3 r4
};
const byte kInstruction_tst_vc_r3_r5[] = {
  0x78, 0xbf, 0x2b, 0x42 // It vc; tst vc r3 r5
};
const byte kInstruction_tst_vc_r3_r6[] = {
  0x78, 0xbf, 0x33, 0x42 // It vc; tst vc r3 r6
};
const byte kInstruction_tst_vc_r3_r7[] = {
  0x78, 0xbf, 0x3b, 0x42 // It vc; tst vc r3 r7
};
const byte kInstruction_tst_vc_r4_r0[] = {
  0x78, 0xbf, 0x04, 0x42 // It vc; tst vc r4 r0
};
const byte kInstruction_tst_vc_r4_r1[] = {
  0x78, 0xbf, 0x0c, 0x42 // It vc; tst vc r4 r1
};
const byte kInstruction_tst_vc_r4_r2[] = {
  0x78, 0xbf, 0x14, 0x42 // It vc; tst vc r4 r2
};
const byte kInstruction_tst_vc_r4_r3[] = {
  0x78, 0xbf, 0x1c, 0x42 // It vc; tst vc r4 r3
};
const byte kInstruction_tst_vc_r4_r4[] = {
  0x78, 0xbf, 0x24, 0x42 // It vc; tst vc r4 r4
};
const byte kInstruction_tst_vc_r4_r5[] = {
  0x78, 0xbf, 0x2c, 0x42 // It vc; tst vc r4 r5
};
const byte kInstruction_tst_vc_r4_r6[] = {
  0x78, 0xbf, 0x34, 0x42 // It vc; tst vc r4 r6
};
const byte kInstruction_tst_vc_r4_r7[] = {
  0x78, 0xbf, 0x3c, 0x42 // It vc; tst vc r4 r7
};
const byte kInstruction_tst_vc_r5_r0[] = {
  0x78, 0xbf, 0x05, 0x42 // It vc; tst vc r5 r0
};
const byte kInstruction_tst_vc_r5_r1[] = {
  0x78, 0xbf, 0x0d, 0x42 // It vc; tst vc r5 r1
};
const byte kInstruction_tst_vc_r5_r2[] = {
  0x78, 0xbf, 0x15, 0x42 // It vc; tst vc r5 r2
};
const byte kInstruction_tst_vc_r5_r3[] = {
  0x78, 0xbf, 0x1d, 0x42 // It vc; tst vc r5 r3
};
const byte kInstruction_tst_vc_r5_r4[] = {
  0x78, 0xbf, 0x25, 0x42 // It vc; tst vc r5 r4
};
const byte kInstruction_tst_vc_r5_r5[] = {
  0x78, 0xbf, 0x2d, 0x42 // It vc; tst vc r5 r5
};
const byte kInstruction_tst_vc_r5_r6[] = {
  0x78, 0xbf, 0x35, 0x42 // It vc; tst vc r5 r6
};
const byte kInstruction_tst_vc_r5_r7[] = {
  0x78, 0xbf, 0x3d, 0x42 // It vc; tst vc r5 r7
};
const byte kInstruction_tst_vc_r6_r0[] = {
  0x78, 0xbf, 0x06, 0x42 // It vc; tst vc r6 r0
};
const byte kInstruction_tst_vc_r6_r1[] = {
  0x78, 0xbf, 0x0e, 0x42 // It vc; tst vc r6 r1
};
const byte kInstruction_tst_vc_r6_r2[] = {
  0x78, 0xbf, 0x16, 0x42 // It vc; tst vc r6 r2
};
const byte kInstruction_tst_vc_r6_r3[] = {
  0x78, 0xbf, 0x1e, 0x42 // It vc; tst vc r6 r3
};
const byte kInstruction_tst_vc_r6_r4[] = {
  0x78, 0xbf, 0x26, 0x42 // It vc; tst vc r6 r4
};
const byte kInstruction_tst_vc_r6_r5[] = {
  0x78, 0xbf, 0x2e, 0x42 // It vc; tst vc r6 r5
};
const byte kInstruction_tst_vc_r6_r6[] = {
  0x78, 0xbf, 0x36, 0x42 // It vc; tst vc r6 r6
};
const byte kInstruction_tst_vc_r6_r7[] = {
  0x78, 0xbf, 0x3e, 0x42 // It vc; tst vc r6 r7
};
const byte kInstruction_tst_vc_r7_r0[] = {
  0x78, 0xbf, 0x07, 0x42 // It vc; tst vc r7 r0
};
const byte kInstruction_tst_vc_r7_r1[] = {
  0x78, 0xbf, 0x0f, 0x42 // It vc; tst vc r7 r1
};
const byte kInstruction_tst_vc_r7_r2[] = {
  0x78, 0xbf, 0x17, 0x42 // It vc; tst vc r7 r2
};
const byte kInstruction_tst_vc_r7_r3[] = {
  0x78, 0xbf, 0x1f, 0x42 // It vc; tst vc r7 r3
};
const byte kInstruction_tst_vc_r7_r4[] = {
  0x78, 0xbf, 0x27, 0x42 // It vc; tst vc r7 r4
};
const byte kInstruction_tst_vc_r7_r5[] = {
  0x78, 0xbf, 0x2f, 0x42 // It vc; tst vc r7 r5
};
const byte kInstruction_tst_vc_r7_r6[] = {
  0x78, 0xbf, 0x37, 0x42 // It vc; tst vc r7 r6
};
const byte kInstruction_tst_vc_r7_r7[] = {
  0x78, 0xbf, 0x3f, 0x42 // It vc; tst vc r7 r7
};
const byte kInstruction_tst_hi_r0_r0[] = {
  0x88, 0xbf, 0x00, 0x42 // It hi; tst hi r0 r0
};
const byte kInstruction_tst_hi_r0_r1[] = {
  0x88, 0xbf, 0x08, 0x42 // It hi; tst hi r0 r1
};
const byte kInstruction_tst_hi_r0_r2[] = {
  0x88, 0xbf, 0x10, 0x42 // It hi; tst hi r0 r2
};
const byte kInstruction_tst_hi_r0_r3[] = {
  0x88, 0xbf, 0x18, 0x42 // It hi; tst hi r0 r3
};
const byte kInstruction_tst_hi_r0_r4[] = {
  0x88, 0xbf, 0x20, 0x42 // It hi; tst hi r0 r4
};
const byte kInstruction_tst_hi_r0_r5[] = {
  0x88, 0xbf, 0x28, 0x42 // It hi; tst hi r0 r5
};
const byte kInstruction_tst_hi_r0_r6[] = {
  0x88, 0xbf, 0x30, 0x42 // It hi; tst hi r0 r6
};
const byte kInstruction_tst_hi_r0_r7[] = {
  0x88, 0xbf, 0x38, 0x42 // It hi; tst hi r0 r7
};
const byte kInstruction_tst_hi_r1_r0[] = {
  0x88, 0xbf, 0x01, 0x42 // It hi; tst hi r1 r0
};
const byte kInstruction_tst_hi_r1_r1[] = {
  0x88, 0xbf, 0x09, 0x42 // It hi; tst hi r1 r1
};
const byte kInstruction_tst_hi_r1_r2[] = {
  0x88, 0xbf, 0x11, 0x42 // It hi; tst hi r1 r2
};
const byte kInstruction_tst_hi_r1_r3[] = {
  0x88, 0xbf, 0x19, 0x42 // It hi; tst hi r1 r3
};
const byte kInstruction_tst_hi_r1_r4[] = {
  0x88, 0xbf, 0x21, 0x42 // It hi; tst hi r1 r4
};
const byte kInstruction_tst_hi_r1_r5[] = {
  0x88, 0xbf, 0x29, 0x42 // It hi; tst hi r1 r5
};
const byte kInstruction_tst_hi_r1_r6[] = {
  0x88, 0xbf, 0x31, 0x42 // It hi; tst hi r1 r6
};
const byte kInstruction_tst_hi_r1_r7[] = {
  0x88, 0xbf, 0x39, 0x42 // It hi; tst hi r1 r7
};
const byte kInstruction_tst_hi_r2_r0[] = {
  0x88, 0xbf, 0x02, 0x42 // It hi; tst hi r2 r0
};
const byte kInstruction_tst_hi_r2_r1[] = {
  0x88, 0xbf, 0x0a, 0x42 // It hi; tst hi r2 r1
};
const byte kInstruction_tst_hi_r2_r2[] = {
  0x88, 0xbf, 0x12, 0x42 // It hi; tst hi r2 r2
};
const byte kInstruction_tst_hi_r2_r3[] = {
  0x88, 0xbf, 0x1a, 0x42 // It hi; tst hi r2 r3
};
const byte kInstruction_tst_hi_r2_r4[] = {
  0x88, 0xbf, 0x22, 0x42 // It hi; tst hi r2 r4
};
const byte kInstruction_tst_hi_r2_r5[] = {
  0x88, 0xbf, 0x2a, 0x42 // It hi; tst hi r2 r5
};
const byte kInstruction_tst_hi_r2_r6[] = {
  0x88, 0xbf, 0x32, 0x42 // It hi; tst hi r2 r6
};
const byte kInstruction_tst_hi_r2_r7[] = {
  0x88, 0xbf, 0x3a, 0x42 // It hi; tst hi r2 r7
};
const byte kInstruction_tst_hi_r3_r0[] = {
  0x88, 0xbf, 0x03, 0x42 // It hi; tst hi r3 r0
};
const byte kInstruction_tst_hi_r3_r1[] = {
  0x88, 0xbf, 0x0b, 0x42 // It hi; tst hi r3 r1
};
const byte kInstruction_tst_hi_r3_r2[] = {
  0x88, 0xbf, 0x13, 0x42 // It hi; tst hi r3 r2
};
const byte kInstruction_tst_hi_r3_r3[] = {
  0x88, 0xbf, 0x1b, 0x42 // It hi; tst hi r3 r3
};
const byte kInstruction_tst_hi_r3_r4[] = {
  0x88, 0xbf, 0x23, 0x42 // It hi; tst hi r3 r4
};
const byte kInstruction_tst_hi_r3_r5[] = {
  0x88, 0xbf, 0x2b, 0x42 // It hi; tst hi r3 r5
};
const byte kInstruction_tst_hi_r3_r6[] = {
  0x88, 0xbf, 0x33, 0x42 // It hi; tst hi r3 r6
};
const byte kInstruction_tst_hi_r3_r7[] = {
  0x88, 0xbf, 0x3b, 0x42 // It hi; tst hi r3 r7
};
const byte kInstruction_tst_hi_r4_r0[] = {
  0x88, 0xbf, 0x04, 0x42 // It hi; tst hi r4 r0
};
const byte kInstruction_tst_hi_r4_r1[] = {
  0x88, 0xbf, 0x0c, 0x42 // It hi; tst hi r4 r1
};
const byte kInstruction_tst_hi_r4_r2[] = {
  0x88, 0xbf, 0x14, 0x42 // It hi; tst hi r4 r2
};
const byte kInstruction_tst_hi_r4_r3[] = {
  0x88, 0xbf, 0x1c, 0x42 // It hi; tst hi r4 r3
};
const byte kInstruction_tst_hi_r4_r4[] = {
  0x88, 0xbf, 0x24, 0x42 // It hi; tst hi r4 r4
};
const byte kInstruction_tst_hi_r4_r5[] = {
  0x88, 0xbf, 0x2c, 0x42 // It hi; tst hi r4 r5
};
const byte kInstruction_tst_hi_r4_r6[] = {
  0x88, 0xbf, 0x34, 0x42 // It hi; tst hi r4 r6
};
const byte kInstruction_tst_hi_r4_r7[] = {
  0x88, 0xbf, 0x3c, 0x42 // It hi; tst hi r4 r7
};
const byte kInstruction_tst_hi_r5_r0[] = {
  0x88, 0xbf, 0x05, 0x42 // It hi; tst hi r5 r0
};
const byte kInstruction_tst_hi_r5_r1[] = {
  0x88, 0xbf, 0x0d, 0x42 // It hi; tst hi r5 r1
};
const byte kInstruction_tst_hi_r5_r2[] = {
  0x88, 0xbf, 0x15, 0x42 // It hi; tst hi r5 r2
};
const byte kInstruction_tst_hi_r5_r3[] = {
  0x88, 0xbf, 0x1d, 0x42 // It hi; tst hi r5 r3
};
const byte kInstruction_tst_hi_r5_r4[] = {
  0x88, 0xbf, 0x25, 0x42 // It hi; tst hi r5 r4
};
const byte kInstruction_tst_hi_r5_r5[] = {
  0x88, 0xbf, 0x2d, 0x42 // It hi; tst hi r5 r5
};
const byte kInstruction_tst_hi_r5_r6[] = {
  0x88, 0xbf, 0x35, 0x42 // It hi; tst hi r5 r6
};
const byte kInstruction_tst_hi_r5_r7[] = {
  0x88, 0xbf, 0x3d, 0x42 // It hi; tst hi r5 r7
};
const byte kInstruction_tst_hi_r6_r0[] = {
  0x88, 0xbf, 0x06, 0x42 // It hi; tst hi r6 r0
};
const byte kInstruction_tst_hi_r6_r1[] = {
  0x88, 0xbf, 0x0e, 0x42 // It hi; tst hi r6 r1
};
const byte kInstruction_tst_hi_r6_r2[] = {
  0x88, 0xbf, 0x16, 0x42 // It hi; tst hi r6 r2
};
const byte kInstruction_tst_hi_r6_r3[] = {
  0x88, 0xbf, 0x1e, 0x42 // It hi; tst hi r6 r3
};
const byte kInstruction_tst_hi_r6_r4[] = {
  0x88, 0xbf, 0x26, 0x42 // It hi; tst hi r6 r4
};
const byte kInstruction_tst_hi_r6_r5[] = {
  0x88, 0xbf, 0x2e, 0x42 // It hi; tst hi r6 r5
};
const byte kInstruction_tst_hi_r6_r6[] = {
  0x88, 0xbf, 0x36, 0x42 // It hi; tst hi r6 r6
};
const byte kInstruction_tst_hi_r6_r7[] = {
  0x88, 0xbf, 0x3e, 0x42 // It hi; tst hi r6 r7
};
const byte kInstruction_tst_hi_r7_r0[] = {
  0x88, 0xbf, 0x07, 0x42 // It hi; tst hi r7 r0
};
const byte kInstruction_tst_hi_r7_r1[] = {
  0x88, 0xbf, 0x0f, 0x42 // It hi; tst hi r7 r1
};
const byte kInstruction_tst_hi_r7_r2[] = {
  0x88, 0xbf, 0x17, 0x42 // It hi; tst hi r7 r2
};
const byte kInstruction_tst_hi_r7_r3[] = {
  0x88, 0xbf, 0x1f, 0x42 // It hi; tst hi r7 r3
};
const byte kInstruction_tst_hi_r7_r4[] = {
  0x88, 0xbf, 0x27, 0x42 // It hi; tst hi r7 r4
};
const byte kInstruction_tst_hi_r7_r5[] = {
  0x88, 0xbf, 0x2f, 0x42 // It hi; tst hi r7 r5
};
const byte kInstruction_tst_hi_r7_r6[] = {
  0x88, 0xbf, 0x37, 0x42 // It hi; tst hi r7 r6
};
const byte kInstruction_tst_hi_r7_r7[] = {
  0x88, 0xbf, 0x3f, 0x42 // It hi; tst hi r7 r7
};
const byte kInstruction_tst_ls_r0_r0[] = {
  0x98, 0xbf, 0x00, 0x42 // It ls; tst ls r0 r0
};
const byte kInstruction_tst_ls_r0_r1[] = {
  0x98, 0xbf, 0x08, 0x42 // It ls; tst ls r0 r1
};
const byte kInstruction_tst_ls_r0_r2[] = {
  0x98, 0xbf, 0x10, 0x42 // It ls; tst ls r0 r2
};
const byte kInstruction_tst_ls_r0_r3[] = {
  0x98, 0xbf, 0x18, 0x42 // It ls; tst ls r0 r3
};
const byte kInstruction_tst_ls_r0_r4[] = {
  0x98, 0xbf, 0x20, 0x42 // It ls; tst ls r0 r4
};
const byte kInstruction_tst_ls_r0_r5[] = {
  0x98, 0xbf, 0x28, 0x42 // It ls; tst ls r0 r5
};
const byte kInstruction_tst_ls_r0_r6[] = {
  0x98, 0xbf, 0x30, 0x42 // It ls; tst ls r0 r6
};
const byte kInstruction_tst_ls_r0_r7[] = {
  0x98, 0xbf, 0x38, 0x42 // It ls; tst ls r0 r7
};
const byte kInstruction_tst_ls_r1_r0[] = {
  0x98, 0xbf, 0x01, 0x42 // It ls; tst ls r1 r0
};
const byte kInstruction_tst_ls_r1_r1[] = {
  0x98, 0xbf, 0x09, 0x42 // It ls; tst ls r1 r1
};
const byte kInstruction_tst_ls_r1_r2[] = {
  0x98, 0xbf, 0x11, 0x42 // It ls; tst ls r1 r2
};
const byte kInstruction_tst_ls_r1_r3[] = {
  0x98, 0xbf, 0x19, 0x42 // It ls; tst ls r1 r3
};
const byte kInstruction_tst_ls_r1_r4[] = {
  0x98, 0xbf, 0x21, 0x42 // It ls; tst ls r1 r4
};
const byte kInstruction_tst_ls_r1_r5[] = {
  0x98, 0xbf, 0x29, 0x42 // It ls; tst ls r1 r5
};
const byte kInstruction_tst_ls_r1_r6[] = {
  0x98, 0xbf, 0x31, 0x42 // It ls; tst ls r1 r6
};
const byte kInstruction_tst_ls_r1_r7[] = {
  0x98, 0xbf, 0x39, 0x42 // It ls; tst ls r1 r7
};
const byte kInstruction_tst_ls_r2_r0[] = {
  0x98, 0xbf, 0x02, 0x42 // It ls; tst ls r2 r0
};
const byte kInstruction_tst_ls_r2_r1[] = {
  0x98, 0xbf, 0x0a, 0x42 // It ls; tst ls r2 r1
};
const byte kInstruction_tst_ls_r2_r2[] = {
  0x98, 0xbf, 0x12, 0x42 // It ls; tst ls r2 r2
};
const byte kInstruction_tst_ls_r2_r3[] = {
  0x98, 0xbf, 0x1a, 0x42 // It ls; tst ls r2 r3
};
const byte kInstruction_tst_ls_r2_r4[] = {
  0x98, 0xbf, 0x22, 0x42 // It ls; tst ls r2 r4
};
const byte kInstruction_tst_ls_r2_r5[] = {
  0x98, 0xbf, 0x2a, 0x42 // It ls; tst ls r2 r5
};
const byte kInstruction_tst_ls_r2_r6[] = {
  0x98, 0xbf, 0x32, 0x42 // It ls; tst ls r2 r6
};
const byte kInstruction_tst_ls_r2_r7[] = {
  0x98, 0xbf, 0x3a, 0x42 // It ls; tst ls r2 r7
};
const byte kInstruction_tst_ls_r3_r0[] = {
  0x98, 0xbf, 0x03, 0x42 // It ls; tst ls r3 r0
};
const byte kInstruction_tst_ls_r3_r1[] = {
  0x98, 0xbf, 0x0b, 0x42 // It ls; tst ls r3 r1
};
const byte kInstruction_tst_ls_r3_r2[] = {
  0x98, 0xbf, 0x13, 0x42 // It ls; tst ls r3 r2
};
const byte kInstruction_tst_ls_r3_r3[] = {
  0x98, 0xbf, 0x1b, 0x42 // It ls; tst ls r3 r3
};
const byte kInstruction_tst_ls_r3_r4[] = {
  0x98, 0xbf, 0x23, 0x42 // It ls; tst ls r3 r4
};
const byte kInstruction_tst_ls_r3_r5[] = {
  0x98, 0xbf, 0x2b, 0x42 // It ls; tst ls r3 r5
};
const byte kInstruction_tst_ls_r3_r6[] = {
  0x98, 0xbf, 0x33, 0x42 // It ls; tst ls r3 r6
};
const byte kInstruction_tst_ls_r3_r7[] = {
  0x98, 0xbf, 0x3b, 0x42 // It ls; tst ls r3 r7
};
const byte kInstruction_tst_ls_r4_r0[] = {
  0x98, 0xbf, 0x04, 0x42 // It ls; tst ls r4 r0
};
const byte kInstruction_tst_ls_r4_r1[] = {
  0x98, 0xbf, 0x0c, 0x42 // It ls; tst ls r4 r1
};
const byte kInstruction_tst_ls_r4_r2[] = {
  0x98, 0xbf, 0x14, 0x42 // It ls; tst ls r4 r2
};
const byte kInstruction_tst_ls_r4_r3[] = {
  0x98, 0xbf, 0x1c, 0x42 // It ls; tst ls r4 r3
};
const byte kInstruction_tst_ls_r4_r4[] = {
  0x98, 0xbf, 0x24, 0x42 // It ls; tst ls r4 r4
};
const byte kInstruction_tst_ls_r4_r5[] = {
  0x98, 0xbf, 0x2c, 0x42 // It ls; tst ls r4 r5
};
const byte kInstruction_tst_ls_r4_r6[] = {
  0x98, 0xbf, 0x34, 0x42 // It ls; tst ls r4 r6
};
const byte kInstruction_tst_ls_r4_r7[] = {
  0x98, 0xbf, 0x3c, 0x42 // It ls; tst ls r4 r7
};
const byte kInstruction_tst_ls_r5_r0[] = {
  0x98, 0xbf, 0x05, 0x42 // It ls; tst ls r5 r0
};
const byte kInstruction_tst_ls_r5_r1[] = {
  0x98, 0xbf, 0x0d, 0x42 // It ls; tst ls r5 r1
};
const byte kInstruction_tst_ls_r5_r2[] = {
  0x98, 0xbf, 0x15, 0x42 // It ls; tst ls r5 r2
};
const byte kInstruction_tst_ls_r5_r3[] = {
  0x98, 0xbf, 0x1d, 0x42 // It ls; tst ls r5 r3
};
const byte kInstruction_tst_ls_r5_r4[] = {
  0x98, 0xbf, 0x25, 0x42 // It ls; tst ls r5 r4
};
const byte kInstruction_tst_ls_r5_r5[] = {
  0x98, 0xbf, 0x2d, 0x42 // It ls; tst ls r5 r5
};
const byte kInstruction_tst_ls_r5_r6[] = {
  0x98, 0xbf, 0x35, 0x42 // It ls; tst ls r5 r6
};
const byte kInstruction_tst_ls_r5_r7[] = {
  0x98, 0xbf, 0x3d, 0x42 // It ls; tst ls r5 r7
};
const byte kInstruction_tst_ls_r6_r0[] = {
  0x98, 0xbf, 0x06, 0x42 // It ls; tst ls r6 r0
};
const byte kInstruction_tst_ls_r6_r1[] = {
  0x98, 0xbf, 0x0e, 0x42 // It ls; tst ls r6 r1
};
const byte kInstruction_tst_ls_r6_r2[] = {
  0x98, 0xbf, 0x16, 0x42 // It ls; tst ls r6 r2
};
const byte kInstruction_tst_ls_r6_r3[] = {
  0x98, 0xbf, 0x1e, 0x42 // It ls; tst ls r6 r3
};
const byte kInstruction_tst_ls_r6_r4[] = {
  0x98, 0xbf, 0x26, 0x42 // It ls; tst ls r6 r4
};
const byte kInstruction_tst_ls_r6_r5[] = {
  0x98, 0xbf, 0x2e, 0x42 // It ls; tst ls r6 r5
};
const byte kInstruction_tst_ls_r6_r6[] = {
  0x98, 0xbf, 0x36, 0x42 // It ls; tst ls r6 r6
};
const byte kInstruction_tst_ls_r6_r7[] = {
  0x98, 0xbf, 0x3e, 0x42 // It ls; tst ls r6 r7
};
const byte kInstruction_tst_ls_r7_r0[] = {
  0x98, 0xbf, 0x07, 0x42 // It ls; tst ls r7 r0
};
const byte kInstruction_tst_ls_r7_r1[] = {
  0x98, 0xbf, 0x0f, 0x42 // It ls; tst ls r7 r1
};
const byte kInstruction_tst_ls_r7_r2[] = {
  0x98, 0xbf, 0x17, 0x42 // It ls; tst ls r7 r2
};
const byte kInstruction_tst_ls_r7_r3[] = {
  0x98, 0xbf, 0x1f, 0x42 // It ls; tst ls r7 r3
};
const byte kInstruction_tst_ls_r7_r4[] = {
  0x98, 0xbf, 0x27, 0x42 // It ls; tst ls r7 r4
};
const byte kInstruction_tst_ls_r7_r5[] = {
  0x98, 0xbf, 0x2f, 0x42 // It ls; tst ls r7 r5
};
const byte kInstruction_tst_ls_r7_r6[] = {
  0x98, 0xbf, 0x37, 0x42 // It ls; tst ls r7 r6
};
const byte kInstruction_tst_ls_r7_r7[] = {
  0x98, 0xbf, 0x3f, 0x42 // It ls; tst ls r7 r7
};
const byte kInstruction_tst_ge_r0_r0[] = {
  0xa8, 0xbf, 0x00, 0x42 // It ge; tst ge r0 r0
};
const byte kInstruction_tst_ge_r0_r1[] = {
  0xa8, 0xbf, 0x08, 0x42 // It ge; tst ge r0 r1
};
const byte kInstruction_tst_ge_r0_r2[] = {
  0xa8, 0xbf, 0x10, 0x42 // It ge; tst ge r0 r2
};
const byte kInstruction_tst_ge_r0_r3[] = {
  0xa8, 0xbf, 0x18, 0x42 // It ge; tst ge r0 r3
};
const byte kInstruction_tst_ge_r0_r4[] = {
  0xa8, 0xbf, 0x20, 0x42 // It ge; tst ge r0 r4
};
const byte kInstruction_tst_ge_r0_r5[] = {
  0xa8, 0xbf, 0x28, 0x42 // It ge; tst ge r0 r5
};
const byte kInstruction_tst_ge_r0_r6[] = {
  0xa8, 0xbf, 0x30, 0x42 // It ge; tst ge r0 r6
};
const byte kInstruction_tst_ge_r0_r7[] = {
  0xa8, 0xbf, 0x38, 0x42 // It ge; tst ge r0 r7
};
const byte kInstruction_tst_ge_r1_r0[] = {
  0xa8, 0xbf, 0x01, 0x42 // It ge; tst ge r1 r0
};
const byte kInstruction_tst_ge_r1_r1[] = {
  0xa8, 0xbf, 0x09, 0x42 // It ge; tst ge r1 r1
};
const byte kInstruction_tst_ge_r1_r2[] = {
  0xa8, 0xbf, 0x11, 0x42 // It ge; tst ge r1 r2
};
const byte kInstruction_tst_ge_r1_r3[] = {
  0xa8, 0xbf, 0x19, 0x42 // It ge; tst ge r1 r3
};
const byte kInstruction_tst_ge_r1_r4[] = {
  0xa8, 0xbf, 0x21, 0x42 // It ge; tst ge r1 r4
};
const byte kInstruction_tst_ge_r1_r5[] = {
  0xa8, 0xbf, 0x29, 0x42 // It ge; tst ge r1 r5
};
const byte kInstruction_tst_ge_r1_r6[] = {
  0xa8, 0xbf, 0x31, 0x42 // It ge; tst ge r1 r6
};
const byte kInstruction_tst_ge_r1_r7[] = {
  0xa8, 0xbf, 0x39, 0x42 // It ge; tst ge r1 r7
};
const byte kInstruction_tst_ge_r2_r0[] = {
  0xa8, 0xbf, 0x02, 0x42 // It ge; tst ge r2 r0
};
const byte kInstruction_tst_ge_r2_r1[] = {
  0xa8, 0xbf, 0x0a, 0x42 // It ge; tst ge r2 r1
};
const byte kInstruction_tst_ge_r2_r2[] = {
  0xa8, 0xbf, 0x12, 0x42 // It ge; tst ge r2 r2
};
const byte kInstruction_tst_ge_r2_r3[] = {
  0xa8, 0xbf, 0x1a, 0x42 // It ge; tst ge r2 r3
};
const byte kInstruction_tst_ge_r2_r4[] = {
  0xa8, 0xbf, 0x22, 0x42 // It ge; tst ge r2 r4
};
const byte kInstruction_tst_ge_r2_r5[] = {
  0xa8, 0xbf, 0x2a, 0x42 // It ge; tst ge r2 r5
};
const byte kInstruction_tst_ge_r2_r6[] = {
  0xa8, 0xbf, 0x32, 0x42 // It ge; tst ge r2 r6
};
const byte kInstruction_tst_ge_r2_r7[] = {
  0xa8, 0xbf, 0x3a, 0x42 // It ge; tst ge r2 r7
};
const byte kInstruction_tst_ge_r3_r0[] = {
  0xa8, 0xbf, 0x03, 0x42 // It ge; tst ge r3 r0
};
const byte kInstruction_tst_ge_r3_r1[] = {
  0xa8, 0xbf, 0x0b, 0x42 // It ge; tst ge r3 r1
};
const byte kInstruction_tst_ge_r3_r2[] = {
  0xa8, 0xbf, 0x13, 0x42 // It ge; tst ge r3 r2
};
const byte kInstruction_tst_ge_r3_r3[] = {
  0xa8, 0xbf, 0x1b, 0x42 // It ge; tst ge r3 r3
};
const byte kInstruction_tst_ge_r3_r4[] = {
  0xa8, 0xbf, 0x23, 0x42 // It ge; tst ge r3 r4
};
const byte kInstruction_tst_ge_r3_r5[] = {
  0xa8, 0xbf, 0x2b, 0x42 // It ge; tst ge r3 r5
};
const byte kInstruction_tst_ge_r3_r6[] = {
  0xa8, 0xbf, 0x33, 0x42 // It ge; tst ge r3 r6
};
const byte kInstruction_tst_ge_r3_r7[] = {
  0xa8, 0xbf, 0x3b, 0x42 // It ge; tst ge r3 r7
};
const byte kInstruction_tst_ge_r4_r0[] = {
  0xa8, 0xbf, 0x04, 0x42 // It ge; tst ge r4 r0
};
const byte kInstruction_tst_ge_r4_r1[] = {
  0xa8, 0xbf, 0x0c, 0x42 // It ge; tst ge r4 r1
};
const byte kInstruction_tst_ge_r4_r2[] = {
  0xa8, 0xbf, 0x14, 0x42 // It ge; tst ge r4 r2
};
const byte kInstruction_tst_ge_r4_r3[] = {
  0xa8, 0xbf, 0x1c, 0x42 // It ge; tst ge r4 r3
};
const byte kInstruction_tst_ge_r4_r4[] = {
  0xa8, 0xbf, 0x24, 0x42 // It ge; tst ge r4 r4
};
const byte kInstruction_tst_ge_r4_r5[] = {
  0xa8, 0xbf, 0x2c, 0x42 // It ge; tst ge r4 r5
};
const byte kInstruction_tst_ge_r4_r6[] = {
  0xa8, 0xbf, 0x34, 0x42 // It ge; tst ge r4 r6
};
const byte kInstruction_tst_ge_r4_r7[] = {
  0xa8, 0xbf, 0x3c, 0x42 // It ge; tst ge r4 r7
};
const byte kInstruction_tst_ge_r5_r0[] = {
  0xa8, 0xbf, 0x05, 0x42 // It ge; tst ge r5 r0
};
const byte kInstruction_tst_ge_r5_r1[] = {
  0xa8, 0xbf, 0x0d, 0x42 // It ge; tst ge r5 r1
};
const byte kInstruction_tst_ge_r5_r2[] = {
  0xa8, 0xbf, 0x15, 0x42 // It ge; tst ge r5 r2
};
const byte kInstruction_tst_ge_r5_r3[] = {
  0xa8, 0xbf, 0x1d, 0x42 // It ge; tst ge r5 r3
};
const byte kInstruction_tst_ge_r5_r4[] = {
  0xa8, 0xbf, 0x25, 0x42 // It ge; tst ge r5 r4
};
const byte kInstruction_tst_ge_r5_r5[] = {
  0xa8, 0xbf, 0x2d, 0x42 // It ge; tst ge r5 r5
};
const byte kInstruction_tst_ge_r5_r6[] = {
  0xa8, 0xbf, 0x35, 0x42 // It ge; tst ge r5 r6
};
const byte kInstruction_tst_ge_r5_r7[] = {
  0xa8, 0xbf, 0x3d, 0x42 // It ge; tst ge r5 r7
};
const byte kInstruction_tst_ge_r6_r0[] = {
  0xa8, 0xbf, 0x06, 0x42 // It ge; tst ge r6 r0
};
const byte kInstruction_tst_ge_r6_r1[] = {
  0xa8, 0xbf, 0x0e, 0x42 // It ge; tst ge r6 r1
};
const byte kInstruction_tst_ge_r6_r2[] = {
  0xa8, 0xbf, 0x16, 0x42 // It ge; tst ge r6 r2
};
const byte kInstruction_tst_ge_r6_r3[] = {
  0xa8, 0xbf, 0x1e, 0x42 // It ge; tst ge r6 r3
};
const byte kInstruction_tst_ge_r6_r4[] = {
  0xa8, 0xbf, 0x26, 0x42 // It ge; tst ge r6 r4
};
const byte kInstruction_tst_ge_r6_r5[] = {
  0xa8, 0xbf, 0x2e, 0x42 // It ge; tst ge r6 r5
};
const byte kInstruction_tst_ge_r6_r6[] = {
  0xa8, 0xbf, 0x36, 0x42 // It ge; tst ge r6 r6
};
const byte kInstruction_tst_ge_r6_r7[] = {
  0xa8, 0xbf, 0x3e, 0x42 // It ge; tst ge r6 r7
};
const byte kInstruction_tst_ge_r7_r0[] = {
  0xa8, 0xbf, 0x07, 0x42 // It ge; tst ge r7 r0
};
const byte kInstruction_tst_ge_r7_r1[] = {
  0xa8, 0xbf, 0x0f, 0x42 // It ge; tst ge r7 r1
};
const byte kInstruction_tst_ge_r7_r2[] = {
  0xa8, 0xbf, 0x17, 0x42 // It ge; tst ge r7 r2
};
const byte kInstruction_tst_ge_r7_r3[] = {
  0xa8, 0xbf, 0x1f, 0x42 // It ge; tst ge r7 r3
};
const byte kInstruction_tst_ge_r7_r4[] = {
  0xa8, 0xbf, 0x27, 0x42 // It ge; tst ge r7 r4
};
const byte kInstruction_tst_ge_r7_r5[] = {
  0xa8, 0xbf, 0x2f, 0x42 // It ge; tst ge r7 r5
};
const byte kInstruction_tst_ge_r7_r6[] = {
  0xa8, 0xbf, 0x37, 0x42 // It ge; tst ge r7 r6
};
const byte kInstruction_tst_ge_r7_r7[] = {
  0xa8, 0xbf, 0x3f, 0x42 // It ge; tst ge r7 r7
};
const byte kInstruction_tst_lt_r0_r0[] = {
  0xb8, 0xbf, 0x00, 0x42 // It lt; tst lt r0 r0
};
const byte kInstruction_tst_lt_r0_r1[] = {
  0xb8, 0xbf, 0x08, 0x42 // It lt; tst lt r0 r1
};
const byte kInstruction_tst_lt_r0_r2[] = {
  0xb8, 0xbf, 0x10, 0x42 // It lt; tst lt r0 r2
};
const byte kInstruction_tst_lt_r0_r3[] = {
  0xb8, 0xbf, 0x18, 0x42 // It lt; tst lt r0 r3
};
const byte kInstruction_tst_lt_r0_r4[] = {
  0xb8, 0xbf, 0x20, 0x42 // It lt; tst lt r0 r4
};
const byte kInstruction_tst_lt_r0_r5[] = {
  0xb8, 0xbf, 0x28, 0x42 // It lt; tst lt r0 r5
};
const byte kInstruction_tst_lt_r0_r6[] = {
  0xb8, 0xbf, 0x30, 0x42 // It lt; tst lt r0 r6
};
const byte kInstruction_tst_lt_r0_r7[] = {
  0xb8, 0xbf, 0x38, 0x42 // It lt; tst lt r0 r7
};
const byte kInstruction_tst_lt_r1_r0[] = {
  0xb8, 0xbf, 0x01, 0x42 // It lt; tst lt r1 r0
};
const byte kInstruction_tst_lt_r1_r1[] = {
  0xb8, 0xbf, 0x09, 0x42 // It lt; tst lt r1 r1
};
const byte kInstruction_tst_lt_r1_r2[] = {
  0xb8, 0xbf, 0x11, 0x42 // It lt; tst lt r1 r2
};
const byte kInstruction_tst_lt_r1_r3[] = {
  0xb8, 0xbf, 0x19, 0x42 // It lt; tst lt r1 r3
};
const byte kInstruction_tst_lt_r1_r4[] = {
  0xb8, 0xbf, 0x21, 0x42 // It lt; tst lt r1 r4
};
const byte kInstruction_tst_lt_r1_r5[] = {
  0xb8, 0xbf, 0x29, 0x42 // It lt; tst lt r1 r5
};
const byte kInstruction_tst_lt_r1_r6[] = {
  0xb8, 0xbf, 0x31, 0x42 // It lt; tst lt r1 r6
};
const byte kInstruction_tst_lt_r1_r7[] = {
  0xb8, 0xbf, 0x39, 0x42 // It lt; tst lt r1 r7
};
const byte kInstruction_tst_lt_r2_r0[] = {
  0xb8, 0xbf, 0x02, 0x42 // It lt; tst lt r2 r0
};
const byte kInstruction_tst_lt_r2_r1[] = {
  0xb8, 0xbf, 0x0a, 0x42 // It lt; tst lt r2 r1
};
const byte kInstruction_tst_lt_r2_r2[] = {
  0xb8, 0xbf, 0x12, 0x42 // It lt; tst lt r2 r2
};
const byte kInstruction_tst_lt_r2_r3[] = {
  0xb8, 0xbf, 0x1a, 0x42 // It lt; tst lt r2 r3
};
const byte kInstruction_tst_lt_r2_r4[] = {
  0xb8, 0xbf, 0x22, 0x42 // It lt; tst lt r2 r4
};
const byte kInstruction_tst_lt_r2_r5[] = {
  0xb8, 0xbf, 0x2a, 0x42 // It lt; tst lt r2 r5
};
const byte kInstruction_tst_lt_r2_r6[] = {
  0xb8, 0xbf, 0x32, 0x42 // It lt; tst lt r2 r6
};
const byte kInstruction_tst_lt_r2_r7[] = {
  0xb8, 0xbf, 0x3a, 0x42 // It lt; tst lt r2 r7
};
const byte kInstruction_tst_lt_r3_r0[] = {
  0xb8, 0xbf, 0x03, 0x42 // It lt; tst lt r3 r0
};
const byte kInstruction_tst_lt_r3_r1[] = {
  0xb8, 0xbf, 0x0b, 0x42 // It lt; tst lt r3 r1
};
const byte kInstruction_tst_lt_r3_r2[] = {
  0xb8, 0xbf, 0x13, 0x42 // It lt; tst lt r3 r2
};
const byte kInstruction_tst_lt_r3_r3[] = {
  0xb8, 0xbf, 0x1b, 0x42 // It lt; tst lt r3 r3
};
const byte kInstruction_tst_lt_r3_r4[] = {
  0xb8, 0xbf, 0x23, 0x42 // It lt; tst lt r3 r4
};
const byte kInstruction_tst_lt_r3_r5[] = {
  0xb8, 0xbf, 0x2b, 0x42 // It lt; tst lt r3 r5
};
const byte kInstruction_tst_lt_r3_r6[] = {
  0xb8, 0xbf, 0x33, 0x42 // It lt; tst lt r3 r6
};
const byte kInstruction_tst_lt_r3_r7[] = {
  0xb8, 0xbf, 0x3b, 0x42 // It lt; tst lt r3 r7
};
const byte kInstruction_tst_lt_r4_r0[] = {
  0xb8, 0xbf, 0x04, 0x42 // It lt; tst lt r4 r0
};
const byte kInstruction_tst_lt_r4_r1[] = {
  0xb8, 0xbf, 0x0c, 0x42 // It lt; tst lt r4 r1
};
const byte kInstruction_tst_lt_r4_r2[] = {
  0xb8, 0xbf, 0x14, 0x42 // It lt; tst lt r4 r2
};
const byte kInstruction_tst_lt_r4_r3[] = {
  0xb8, 0xbf, 0x1c, 0x42 // It lt; tst lt r4 r3
};
const byte kInstruction_tst_lt_r4_r4[] = {
  0xb8, 0xbf, 0x24, 0x42 // It lt; tst lt r4 r4
};
const byte kInstruction_tst_lt_r4_r5[] = {
  0xb8, 0xbf, 0x2c, 0x42 // It lt; tst lt r4 r5
};
const byte kInstruction_tst_lt_r4_r6[] = {
  0xb8, 0xbf, 0x34, 0x42 // It lt; tst lt r4 r6
};
const byte kInstruction_tst_lt_r4_r7[] = {
  0xb8, 0xbf, 0x3c, 0x42 // It lt; tst lt r4 r7
};
const byte kInstruction_tst_lt_r5_r0[] = {
  0xb8, 0xbf, 0x05, 0x42 // It lt; tst lt r5 r0
};
const byte kInstruction_tst_lt_r5_r1[] = {
  0xb8, 0xbf, 0x0d, 0x42 // It lt; tst lt r5 r1
};
const byte kInstruction_tst_lt_r5_r2[] = {
  0xb8, 0xbf, 0x15, 0x42 // It lt; tst lt r5 r2
};
const byte kInstruction_tst_lt_r5_r3[] = {
  0xb8, 0xbf, 0x1d, 0x42 // It lt; tst lt r5 r3
};
const byte kInstruction_tst_lt_r5_r4[] = {
  0xb8, 0xbf, 0x25, 0x42 // It lt; tst lt r5 r4
};
const byte kInstruction_tst_lt_r5_r5[] = {
  0xb8, 0xbf, 0x2d, 0x42 // It lt; tst lt r5 r5
};
const byte kInstruction_tst_lt_r5_r6[] = {
  0xb8, 0xbf, 0x35, 0x42 // It lt; tst lt r5 r6
};
const byte kInstruction_tst_lt_r5_r7[] = {
  0xb8, 0xbf, 0x3d, 0x42 // It lt; tst lt r5 r7
};
const byte kInstruction_tst_lt_r6_r0[] = {
  0xb8, 0xbf, 0x06, 0x42 // It lt; tst lt r6 r0
};
const byte kInstruction_tst_lt_r6_r1[] = {
  0xb8, 0xbf, 0x0e, 0x42 // It lt; tst lt r6 r1
};
const byte kInstruction_tst_lt_r6_r2[] = {
  0xb8, 0xbf, 0x16, 0x42 // It lt; tst lt r6 r2
};
const byte kInstruction_tst_lt_r6_r3[] = {
  0xb8, 0xbf, 0x1e, 0x42 // It lt; tst lt r6 r3
};
const byte kInstruction_tst_lt_r6_r4[] = {
  0xb8, 0xbf, 0x26, 0x42 // It lt; tst lt r6 r4
};
const byte kInstruction_tst_lt_r6_r5[] = {
  0xb8, 0xbf, 0x2e, 0x42 // It lt; tst lt r6 r5
};
const byte kInstruction_tst_lt_r6_r6[] = {
  0xb8, 0xbf, 0x36, 0x42 // It lt; tst lt r6 r6
};
const byte kInstruction_tst_lt_r6_r7[] = {
  0xb8, 0xbf, 0x3e, 0x42 // It lt; tst lt r6 r7
};
const byte kInstruction_tst_lt_r7_r0[] = {
  0xb8, 0xbf, 0x07, 0x42 // It lt; tst lt r7 r0
};
const byte kInstruction_tst_lt_r7_r1[] = {
  0xb8, 0xbf, 0x0f, 0x42 // It lt; tst lt r7 r1
};
const byte kInstruction_tst_lt_r7_r2[] = {
  0xb8, 0xbf, 0x17, 0x42 // It lt; tst lt r7 r2
};
const byte kInstruction_tst_lt_r7_r3[] = {
  0xb8, 0xbf, 0x1f, 0x42 // It lt; tst lt r7 r3
};
const byte kInstruction_tst_lt_r7_r4[] = {
  0xb8, 0xbf, 0x27, 0x42 // It lt; tst lt r7 r4
};
const byte kInstruction_tst_lt_r7_r5[] = {
  0xb8, 0xbf, 0x2f, 0x42 // It lt; tst lt r7 r5
};
const byte kInstruction_tst_lt_r7_r6[] = {
  0xb8, 0xbf, 0x37, 0x42 // It lt; tst lt r7 r6
};
const byte kInstruction_tst_lt_r7_r7[] = {
  0xb8, 0xbf, 0x3f, 0x42 // It lt; tst lt r7 r7
};
const byte kInstruction_tst_gt_r0_r0[] = {
  0xc8, 0xbf, 0x00, 0x42 // It gt; tst gt r0 r0
};
const byte kInstruction_tst_gt_r0_r1[] = {
  0xc8, 0xbf, 0x08, 0x42 // It gt; tst gt r0 r1
};
const byte kInstruction_tst_gt_r0_r2[] = {
  0xc8, 0xbf, 0x10, 0x42 // It gt; tst gt r0 r2
};
const byte kInstruction_tst_gt_r0_r3[] = {
  0xc8, 0xbf, 0x18, 0x42 // It gt; tst gt r0 r3
};
const byte kInstruction_tst_gt_r0_r4[] = {
  0xc8, 0xbf, 0x20, 0x42 // It gt; tst gt r0 r4
};
const byte kInstruction_tst_gt_r0_r5[] = {
  0xc8, 0xbf, 0x28, 0x42 // It gt; tst gt r0 r5
};
const byte kInstruction_tst_gt_r0_r6[] = {
  0xc8, 0xbf, 0x30, 0x42 // It gt; tst gt r0 r6
};
const byte kInstruction_tst_gt_r0_r7[] = {
  0xc8, 0xbf, 0x38, 0x42 // It gt; tst gt r0 r7
};
const byte kInstruction_tst_gt_r1_r0[] = {
  0xc8, 0xbf, 0x01, 0x42 // It gt; tst gt r1 r0
};
const byte kInstruction_tst_gt_r1_r1[] = {
  0xc8, 0xbf, 0x09, 0x42 // It gt; tst gt r1 r1
};
const byte kInstruction_tst_gt_r1_r2[] = {
  0xc8, 0xbf, 0x11, 0x42 // It gt; tst gt r1 r2
};
const byte kInstruction_tst_gt_r1_r3[] = {
  0xc8, 0xbf, 0x19, 0x42 // It gt; tst gt r1 r3
};
const byte kInstruction_tst_gt_r1_r4[] = {
  0xc8, 0xbf, 0x21, 0x42 // It gt; tst gt r1 r4
};
const byte kInstruction_tst_gt_r1_r5[] = {
  0xc8, 0xbf, 0x29, 0x42 // It gt; tst gt r1 r5
};
const byte kInstruction_tst_gt_r1_r6[] = {
  0xc8, 0xbf, 0x31, 0x42 // It gt; tst gt r1 r6
};
const byte kInstruction_tst_gt_r1_r7[] = {
  0xc8, 0xbf, 0x39, 0x42 // It gt; tst gt r1 r7
};
const byte kInstruction_tst_gt_r2_r0[] = {
  0xc8, 0xbf, 0x02, 0x42 // It gt; tst gt r2 r0
};
const byte kInstruction_tst_gt_r2_r1[] = {
  0xc8, 0xbf, 0x0a, 0x42 // It gt; tst gt r2 r1
};
const byte kInstruction_tst_gt_r2_r2[] = {
  0xc8, 0xbf, 0x12, 0x42 // It gt; tst gt r2 r2
};
const byte kInstruction_tst_gt_r2_r3[] = {
  0xc8, 0xbf, 0x1a, 0x42 // It gt; tst gt r2 r3
};
const byte kInstruction_tst_gt_r2_r4[] = {
  0xc8, 0xbf, 0x22, 0x42 // It gt; tst gt r2 r4
};
const byte kInstruction_tst_gt_r2_r5[] = {
  0xc8, 0xbf, 0x2a, 0x42 // It gt; tst gt r2 r5
};
const byte kInstruction_tst_gt_r2_r6[] = {
  0xc8, 0xbf, 0x32, 0x42 // It gt; tst gt r2 r6
};
const byte kInstruction_tst_gt_r2_r7[] = {
  0xc8, 0xbf, 0x3a, 0x42 // It gt; tst gt r2 r7
};
const byte kInstruction_tst_gt_r3_r0[] = {
  0xc8, 0xbf, 0x03, 0x42 // It gt; tst gt r3 r0
};
const byte kInstruction_tst_gt_r3_r1[] = {
  0xc8, 0xbf, 0x0b, 0x42 // It gt; tst gt r3 r1
};
const byte kInstruction_tst_gt_r3_r2[] = {
  0xc8, 0xbf, 0x13, 0x42 // It gt; tst gt r3 r2
};
const byte kInstruction_tst_gt_r3_r3[] = {
  0xc8, 0xbf, 0x1b, 0x42 // It gt; tst gt r3 r3
};
const byte kInstruction_tst_gt_r3_r4[] = {
  0xc8, 0xbf, 0x23, 0x42 // It gt; tst gt r3 r4
};
const byte kInstruction_tst_gt_r3_r5[] = {
  0xc8, 0xbf, 0x2b, 0x42 // It gt; tst gt r3 r5
};
const byte kInstruction_tst_gt_r3_r6[] = {
  0xc8, 0xbf, 0x33, 0x42 // It gt; tst gt r3 r6
};
const byte kInstruction_tst_gt_r3_r7[] = {
  0xc8, 0xbf, 0x3b, 0x42 // It gt; tst gt r3 r7
};
const byte kInstruction_tst_gt_r4_r0[] = {
  0xc8, 0xbf, 0x04, 0x42 // It gt; tst gt r4 r0
};
const byte kInstruction_tst_gt_r4_r1[] = {
  0xc8, 0xbf, 0x0c, 0x42 // It gt; tst gt r4 r1
};
const byte kInstruction_tst_gt_r4_r2[] = {
  0xc8, 0xbf, 0x14, 0x42 // It gt; tst gt r4 r2
};
const byte kInstruction_tst_gt_r4_r3[] = {
  0xc8, 0xbf, 0x1c, 0x42 // It gt; tst gt r4 r3
};
const byte kInstruction_tst_gt_r4_r4[] = {
  0xc8, 0xbf, 0x24, 0x42 // It gt; tst gt r4 r4
};
const byte kInstruction_tst_gt_r4_r5[] = {
  0xc8, 0xbf, 0x2c, 0x42 // It gt; tst gt r4 r5
};
const byte kInstruction_tst_gt_r4_r6[] = {
  0xc8, 0xbf, 0x34, 0x42 // It gt; tst gt r4 r6
};
const byte kInstruction_tst_gt_r4_r7[] = {
  0xc8, 0xbf, 0x3c, 0x42 // It gt; tst gt r4 r7
};
const byte kInstruction_tst_gt_r5_r0[] = {
  0xc8, 0xbf, 0x05, 0x42 // It gt; tst gt r5 r0
};
const byte kInstruction_tst_gt_r5_r1[] = {
  0xc8, 0xbf, 0x0d, 0x42 // It gt; tst gt r5 r1
};
const byte kInstruction_tst_gt_r5_r2[] = {
  0xc8, 0xbf, 0x15, 0x42 // It gt; tst gt r5 r2
};
const byte kInstruction_tst_gt_r5_r3[] = {
  0xc8, 0xbf, 0x1d, 0x42 // It gt; tst gt r5 r3
};
const byte kInstruction_tst_gt_r5_r4[] = {
  0xc8, 0xbf, 0x25, 0x42 // It gt; tst gt r5 r4
};
const byte kInstruction_tst_gt_r5_r5[] = {
  0xc8, 0xbf, 0x2d, 0x42 // It gt; tst gt r5 r5
};
const byte kInstruction_tst_gt_r5_r6[] = {
  0xc8, 0xbf, 0x35, 0x42 // It gt; tst gt r5 r6
};
const byte kInstruction_tst_gt_r5_r7[] = {
  0xc8, 0xbf, 0x3d, 0x42 // It gt; tst gt r5 r7
};
const byte kInstruction_tst_gt_r6_r0[] = {
  0xc8, 0xbf, 0x06, 0x42 // It gt; tst gt r6 r0
};
const byte kInstruction_tst_gt_r6_r1[] = {
  0xc8, 0xbf, 0x0e, 0x42 // It gt; tst gt r6 r1
};
const byte kInstruction_tst_gt_r6_r2[] = {
  0xc8, 0xbf, 0x16, 0x42 // It gt; tst gt r6 r2
};
const byte kInstruction_tst_gt_r6_r3[] = {
  0xc8, 0xbf, 0x1e, 0x42 // It gt; tst gt r6 r3
};
const byte kInstruction_tst_gt_r6_r4[] = {
  0xc8, 0xbf, 0x26, 0x42 // It gt; tst gt r6 r4
};
const byte kInstruction_tst_gt_r6_r5[] = {
  0xc8, 0xbf, 0x2e, 0x42 // It gt; tst gt r6 r5
};
const byte kInstruction_tst_gt_r6_r6[] = {
  0xc8, 0xbf, 0x36, 0x42 // It gt; tst gt r6 r6
};
const byte kInstruction_tst_gt_r6_r7[] = {
  0xc8, 0xbf, 0x3e, 0x42 // It gt; tst gt r6 r7
};
const byte kInstruction_tst_gt_r7_r0[] = {
  0xc8, 0xbf, 0x07, 0x42 // It gt; tst gt r7 r0
};
const byte kInstruction_tst_gt_r7_r1[] = {
  0xc8, 0xbf, 0x0f, 0x42 // It gt; tst gt r7 r1
};
const byte kInstruction_tst_gt_r7_r2[] = {
  0xc8, 0xbf, 0x17, 0x42 // It gt; tst gt r7 r2
};
const byte kInstruction_tst_gt_r7_r3[] = {
  0xc8, 0xbf, 0x1f, 0x42 // It gt; tst gt r7 r3
};
const byte kInstruction_tst_gt_r7_r4[] = {
  0xc8, 0xbf, 0x27, 0x42 // It gt; tst gt r7 r4
};
const byte kInstruction_tst_gt_r7_r5[] = {
  0xc8, 0xbf, 0x2f, 0x42 // It gt; tst gt r7 r5
};
const byte kInstruction_tst_gt_r7_r6[] = {
  0xc8, 0xbf, 0x37, 0x42 // It gt; tst gt r7 r6
};
const byte kInstruction_tst_gt_r7_r7[] = {
  0xc8, 0xbf, 0x3f, 0x42 // It gt; tst gt r7 r7
};
const byte kInstruction_tst_le_r0_r0[] = {
  0xd8, 0xbf, 0x00, 0x42 // It le; tst le r0 r0
};
const byte kInstruction_tst_le_r0_r1[] = {
  0xd8, 0xbf, 0x08, 0x42 // It le; tst le r0 r1
};
const byte kInstruction_tst_le_r0_r2[] = {
  0xd8, 0xbf, 0x10, 0x42 // It le; tst le r0 r2
};
const byte kInstruction_tst_le_r0_r3[] = {
  0xd8, 0xbf, 0x18, 0x42 // It le; tst le r0 r3
};
const byte kInstruction_tst_le_r0_r4[] = {
  0xd8, 0xbf, 0x20, 0x42 // It le; tst le r0 r4
};
const byte kInstruction_tst_le_r0_r5[] = {
  0xd8, 0xbf, 0x28, 0x42 // It le; tst le r0 r5
};
const byte kInstruction_tst_le_r0_r6[] = {
  0xd8, 0xbf, 0x30, 0x42 // It le; tst le r0 r6
};
const byte kInstruction_tst_le_r0_r7[] = {
  0xd8, 0xbf, 0x38, 0x42 // It le; tst le r0 r7
};
const byte kInstruction_tst_le_r1_r0[] = {
  0xd8, 0xbf, 0x01, 0x42 // It le; tst le r1 r0
};
const byte kInstruction_tst_le_r1_r1[] = {
  0xd8, 0xbf, 0x09, 0x42 // It le; tst le r1 r1
};
const byte kInstruction_tst_le_r1_r2[] = {
  0xd8, 0xbf, 0x11, 0x42 // It le; tst le r1 r2
};
const byte kInstruction_tst_le_r1_r3[] = {
  0xd8, 0xbf, 0x19, 0x42 // It le; tst le r1 r3
};
const byte kInstruction_tst_le_r1_r4[] = {
  0xd8, 0xbf, 0x21, 0x42 // It le; tst le r1 r4
};
const byte kInstruction_tst_le_r1_r5[] = {
  0xd8, 0xbf, 0x29, 0x42 // It le; tst le r1 r5
};
const byte kInstruction_tst_le_r1_r6[] = {
  0xd8, 0xbf, 0x31, 0x42 // It le; tst le r1 r6
};
const byte kInstruction_tst_le_r1_r7[] = {
  0xd8, 0xbf, 0x39, 0x42 // It le; tst le r1 r7
};
const byte kInstruction_tst_le_r2_r0[] = {
  0xd8, 0xbf, 0x02, 0x42 // It le; tst le r2 r0
};
const byte kInstruction_tst_le_r2_r1[] = {
  0xd8, 0xbf, 0x0a, 0x42 // It le; tst le r2 r1
};
const byte kInstruction_tst_le_r2_r2[] = {
  0xd8, 0xbf, 0x12, 0x42 // It le; tst le r2 r2
};
const byte kInstruction_tst_le_r2_r3[] = {
  0xd8, 0xbf, 0x1a, 0x42 // It le; tst le r2 r3
};
const byte kInstruction_tst_le_r2_r4[] = {
  0xd8, 0xbf, 0x22, 0x42 // It le; tst le r2 r4
};
const byte kInstruction_tst_le_r2_r5[] = {
  0xd8, 0xbf, 0x2a, 0x42 // It le; tst le r2 r5
};
const byte kInstruction_tst_le_r2_r6[] = {
  0xd8, 0xbf, 0x32, 0x42 // It le; tst le r2 r6
};
const byte kInstruction_tst_le_r2_r7[] = {
  0xd8, 0xbf, 0x3a, 0x42 // It le; tst le r2 r7
};
const byte kInstruction_tst_le_r3_r0[] = {
  0xd8, 0xbf, 0x03, 0x42 // It le; tst le r3 r0
};
const byte kInstruction_tst_le_r3_r1[] = {
  0xd8, 0xbf, 0x0b, 0x42 // It le; tst le r3 r1
};
const byte kInstruction_tst_le_r3_r2[] = {
  0xd8, 0xbf, 0x13, 0x42 // It le; tst le r3 r2
};
const byte kInstruction_tst_le_r3_r3[] = {
  0xd8, 0xbf, 0x1b, 0x42 // It le; tst le r3 r3
};
const byte kInstruction_tst_le_r3_r4[] = {
  0xd8, 0xbf, 0x23, 0x42 // It le; tst le r3 r4
};
const byte kInstruction_tst_le_r3_r5[] = {
  0xd8, 0xbf, 0x2b, 0x42 // It le; tst le r3 r5
};
const byte kInstruction_tst_le_r3_r6[] = {
  0xd8, 0xbf, 0x33, 0x42 // It le; tst le r3 r6
};
const byte kInstruction_tst_le_r3_r7[] = {
  0xd8, 0xbf, 0x3b, 0x42 // It le; tst le r3 r7
};
const byte kInstruction_tst_le_r4_r0[] = {
  0xd8, 0xbf, 0x04, 0x42 // It le; tst le r4 r0
};
const byte kInstruction_tst_le_r4_r1[] = {
  0xd8, 0xbf, 0x0c, 0x42 // It le; tst le r4 r1
};
const byte kInstruction_tst_le_r4_r2[] = {
  0xd8, 0xbf, 0x14, 0x42 // It le; tst le r4 r2
};
const byte kInstruction_tst_le_r4_r3[] = {
  0xd8, 0xbf, 0x1c, 0x42 // It le; tst le r4 r3
};
const byte kInstruction_tst_le_r4_r4[] = {
  0xd8, 0xbf, 0x24, 0x42 // It le; tst le r4 r4
};
const byte kInstruction_tst_le_r4_r5[] = {
  0xd8, 0xbf, 0x2c, 0x42 // It le; tst le r4 r5
};
const byte kInstruction_tst_le_r4_r6[] = {
  0xd8, 0xbf, 0x34, 0x42 // It le; tst le r4 r6
};
const byte kInstruction_tst_le_r4_r7[] = {
  0xd8, 0xbf, 0x3c, 0x42 // It le; tst le r4 r7
};
const byte kInstruction_tst_le_r5_r0[] = {
  0xd8, 0xbf, 0x05, 0x42 // It le; tst le r5 r0
};
const byte kInstruction_tst_le_r5_r1[] = {
  0xd8, 0xbf, 0x0d, 0x42 // It le; tst le r5 r1
};
const byte kInstruction_tst_le_r5_r2[] = {
  0xd8, 0xbf, 0x15, 0x42 // It le; tst le r5 r2
};
const byte kInstruction_tst_le_r5_r3[] = {
  0xd8, 0xbf, 0x1d, 0x42 // It le; tst le r5 r3
};
const byte kInstruction_tst_le_r5_r4[] = {
  0xd8, 0xbf, 0x25, 0x42 // It le; tst le r5 r4
};
const byte kInstruction_tst_le_r5_r5[] = {
  0xd8, 0xbf, 0x2d, 0x42 // It le; tst le r5 r5
};
const byte kInstruction_tst_le_r5_r6[] = {
  0xd8, 0xbf, 0x35, 0x42 // It le; tst le r5 r6
};
const byte kInstruction_tst_le_r5_r7[] = {
  0xd8, 0xbf, 0x3d, 0x42 // It le; tst le r5 r7
};
const byte kInstruction_tst_le_r6_r0[] = {
  0xd8, 0xbf, 0x06, 0x42 // It le; tst le r6 r0
};
const byte kInstruction_tst_le_r6_r1[] = {
  0xd8, 0xbf, 0x0e, 0x42 // It le; tst le r6 r1
};
const byte kInstruction_tst_le_r6_r2[] = {
  0xd8, 0xbf, 0x16, 0x42 // It le; tst le r6 r2
};
const byte kInstruction_tst_le_r6_r3[] = {
  0xd8, 0xbf, 0x1e, 0x42 // It le; tst le r6 r3
};
const byte kInstruction_tst_le_r6_r4[] = {
  0xd8, 0xbf, 0x26, 0x42 // It le; tst le r6 r4
};
const byte kInstruction_tst_le_r6_r5[] = {
  0xd8, 0xbf, 0x2e, 0x42 // It le; tst le r6 r5
};
const byte kInstruction_tst_le_r6_r6[] = {
  0xd8, 0xbf, 0x36, 0x42 // It le; tst le r6 r6
};
const byte kInstruction_tst_le_r6_r7[] = {
  0xd8, 0xbf, 0x3e, 0x42 // It le; tst le r6 r7
};
const byte kInstruction_tst_le_r7_r0[] = {
  0xd8, 0xbf, 0x07, 0x42 // It le; tst le r7 r0
};
const byte kInstruction_tst_le_r7_r1[] = {
  0xd8, 0xbf, 0x0f, 0x42 // It le; tst le r7 r1
};
const byte kInstruction_tst_le_r7_r2[] = {
  0xd8, 0xbf, 0x17, 0x42 // It le; tst le r7 r2
};
const byte kInstruction_tst_le_r7_r3[] = {
  0xd8, 0xbf, 0x1f, 0x42 // It le; tst le r7 r3
};
const byte kInstruction_tst_le_r7_r4[] = {
  0xd8, 0xbf, 0x27, 0x42 // It le; tst le r7 r4
};
const byte kInstruction_tst_le_r7_r5[] = {
  0xd8, 0xbf, 0x2f, 0x42 // It le; tst le r7 r5
};
const byte kInstruction_tst_le_r7_r6[] = {
  0xd8, 0xbf, 0x37, 0x42 // It le; tst le r7 r6
};
const byte kInstruction_tst_le_r7_r7[] = {
  0xd8, 0xbf, 0x3f, 0x42 // It le; tst le r7 r7
};
const TestResult kReferencetst[] = {
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r0),
    kInstruction_tst_eq_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r1),
    kInstruction_tst_eq_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r2),
    kInstruction_tst_eq_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r3),
    kInstruction_tst_eq_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r4),
    kInstruction_tst_eq_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r5),
    kInstruction_tst_eq_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r6),
    kInstruction_tst_eq_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r0_r7),
    kInstruction_tst_eq_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r0),
    kInstruction_tst_eq_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r1),
    kInstruction_tst_eq_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r2),
    kInstruction_tst_eq_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r3),
    kInstruction_tst_eq_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r4),
    kInstruction_tst_eq_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r5),
    kInstruction_tst_eq_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r6),
    kInstruction_tst_eq_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r1_r7),
    kInstruction_tst_eq_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r0),
    kInstruction_tst_eq_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r1),
    kInstruction_tst_eq_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r2),
    kInstruction_tst_eq_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r3),
    kInstruction_tst_eq_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r4),
    kInstruction_tst_eq_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r5),
    kInstruction_tst_eq_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r6),
    kInstruction_tst_eq_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r2_r7),
    kInstruction_tst_eq_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r0),
    kInstruction_tst_eq_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r1),
    kInstruction_tst_eq_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r2),
    kInstruction_tst_eq_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r3),
    kInstruction_tst_eq_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r4),
    kInstruction_tst_eq_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r5),
    kInstruction_tst_eq_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r6),
    kInstruction_tst_eq_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r3_r7),
    kInstruction_tst_eq_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r0),
    kInstruction_tst_eq_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r1),
    kInstruction_tst_eq_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r2),
    kInstruction_tst_eq_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r3),
    kInstruction_tst_eq_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r4),
    kInstruction_tst_eq_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r5),
    kInstruction_tst_eq_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r6),
    kInstruction_tst_eq_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r4_r7),
    kInstruction_tst_eq_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r0),
    kInstruction_tst_eq_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r1),
    kInstruction_tst_eq_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r2),
    kInstruction_tst_eq_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r3),
    kInstruction_tst_eq_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r4),
    kInstruction_tst_eq_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r5),
    kInstruction_tst_eq_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r6),
    kInstruction_tst_eq_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r5_r7),
    kInstruction_tst_eq_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r0),
    kInstruction_tst_eq_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r1),
    kInstruction_tst_eq_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r2),
    kInstruction_tst_eq_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r3),
    kInstruction_tst_eq_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r4),
    kInstruction_tst_eq_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r5),
    kInstruction_tst_eq_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r6),
    kInstruction_tst_eq_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r6_r7),
    kInstruction_tst_eq_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r0),
    kInstruction_tst_eq_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r1),
    kInstruction_tst_eq_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r2),
    kInstruction_tst_eq_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r3),
    kInstruction_tst_eq_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r4),
    kInstruction_tst_eq_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r5),
    kInstruction_tst_eq_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r6),
    kInstruction_tst_eq_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_eq_r7_r7),
    kInstruction_tst_eq_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r0),
    kInstruction_tst_ne_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r1),
    kInstruction_tst_ne_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r2),
    kInstruction_tst_ne_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r3),
    kInstruction_tst_ne_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r4),
    kInstruction_tst_ne_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r5),
    kInstruction_tst_ne_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r6),
    kInstruction_tst_ne_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r0_r7),
    kInstruction_tst_ne_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r0),
    kInstruction_tst_ne_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r1),
    kInstruction_tst_ne_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r2),
    kInstruction_tst_ne_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r3),
    kInstruction_tst_ne_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r4),
    kInstruction_tst_ne_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r5),
    kInstruction_tst_ne_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r6),
    kInstruction_tst_ne_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r1_r7),
    kInstruction_tst_ne_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r0),
    kInstruction_tst_ne_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r1),
    kInstruction_tst_ne_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r2),
    kInstruction_tst_ne_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r3),
    kInstruction_tst_ne_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r4),
    kInstruction_tst_ne_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r5),
    kInstruction_tst_ne_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r6),
    kInstruction_tst_ne_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r2_r7),
    kInstruction_tst_ne_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r0),
    kInstruction_tst_ne_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r1),
    kInstruction_tst_ne_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r2),
    kInstruction_tst_ne_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r3),
    kInstruction_tst_ne_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r4),
    kInstruction_tst_ne_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r5),
    kInstruction_tst_ne_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r6),
    kInstruction_tst_ne_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r3_r7),
    kInstruction_tst_ne_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r0),
    kInstruction_tst_ne_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r1),
    kInstruction_tst_ne_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r2),
    kInstruction_tst_ne_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r3),
    kInstruction_tst_ne_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r4),
    kInstruction_tst_ne_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r5),
    kInstruction_tst_ne_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r6),
    kInstruction_tst_ne_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r4_r7),
    kInstruction_tst_ne_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r0),
    kInstruction_tst_ne_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r1),
    kInstruction_tst_ne_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r2),
    kInstruction_tst_ne_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r3),
    kInstruction_tst_ne_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r4),
    kInstruction_tst_ne_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r5),
    kInstruction_tst_ne_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r6),
    kInstruction_tst_ne_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r5_r7),
    kInstruction_tst_ne_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r0),
    kInstruction_tst_ne_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r1),
    kInstruction_tst_ne_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r2),
    kInstruction_tst_ne_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r3),
    kInstruction_tst_ne_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r4),
    kInstruction_tst_ne_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r5),
    kInstruction_tst_ne_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r6),
    kInstruction_tst_ne_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r6_r7),
    kInstruction_tst_ne_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r0),
    kInstruction_tst_ne_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r1),
    kInstruction_tst_ne_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r2),
    kInstruction_tst_ne_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r3),
    kInstruction_tst_ne_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r4),
    kInstruction_tst_ne_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r5),
    kInstruction_tst_ne_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r6),
    kInstruction_tst_ne_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ne_r7_r7),
    kInstruction_tst_ne_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r0),
    kInstruction_tst_cs_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r1),
    kInstruction_tst_cs_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r2),
    kInstruction_tst_cs_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r3),
    kInstruction_tst_cs_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r4),
    kInstruction_tst_cs_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r5),
    kInstruction_tst_cs_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r6),
    kInstruction_tst_cs_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r0_r7),
    kInstruction_tst_cs_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r0),
    kInstruction_tst_cs_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r1),
    kInstruction_tst_cs_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r2),
    kInstruction_tst_cs_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r3),
    kInstruction_tst_cs_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r4),
    kInstruction_tst_cs_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r5),
    kInstruction_tst_cs_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r6),
    kInstruction_tst_cs_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r1_r7),
    kInstruction_tst_cs_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r0),
    kInstruction_tst_cs_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r1),
    kInstruction_tst_cs_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r2),
    kInstruction_tst_cs_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r3),
    kInstruction_tst_cs_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r4),
    kInstruction_tst_cs_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r5),
    kInstruction_tst_cs_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r6),
    kInstruction_tst_cs_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r2_r7),
    kInstruction_tst_cs_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r0),
    kInstruction_tst_cs_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r1),
    kInstruction_tst_cs_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r2),
    kInstruction_tst_cs_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r3),
    kInstruction_tst_cs_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r4),
    kInstruction_tst_cs_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r5),
    kInstruction_tst_cs_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r6),
    kInstruction_tst_cs_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r3_r7),
    kInstruction_tst_cs_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r0),
    kInstruction_tst_cs_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r1),
    kInstruction_tst_cs_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r2),
    kInstruction_tst_cs_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r3),
    kInstruction_tst_cs_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r4),
    kInstruction_tst_cs_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r5),
    kInstruction_tst_cs_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r6),
    kInstruction_tst_cs_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r4_r7),
    kInstruction_tst_cs_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r0),
    kInstruction_tst_cs_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r1),
    kInstruction_tst_cs_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r2),
    kInstruction_tst_cs_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r3),
    kInstruction_tst_cs_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r4),
    kInstruction_tst_cs_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r5),
    kInstruction_tst_cs_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r6),
    kInstruction_tst_cs_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r5_r7),
    kInstruction_tst_cs_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r0),
    kInstruction_tst_cs_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r1),
    kInstruction_tst_cs_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r2),
    kInstruction_tst_cs_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r3),
    kInstruction_tst_cs_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r4),
    kInstruction_tst_cs_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r5),
    kInstruction_tst_cs_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r6),
    kInstruction_tst_cs_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r6_r7),
    kInstruction_tst_cs_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r0),
    kInstruction_tst_cs_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r1),
    kInstruction_tst_cs_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r2),
    kInstruction_tst_cs_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r3),
    kInstruction_tst_cs_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r4),
    kInstruction_tst_cs_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r5),
    kInstruction_tst_cs_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r6),
    kInstruction_tst_cs_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cs_r7_r7),
    kInstruction_tst_cs_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r0),
    kInstruction_tst_cc_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r1),
    kInstruction_tst_cc_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r2),
    kInstruction_tst_cc_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r3),
    kInstruction_tst_cc_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r4),
    kInstruction_tst_cc_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r5),
    kInstruction_tst_cc_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r6),
    kInstruction_tst_cc_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r0_r7),
    kInstruction_tst_cc_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r0),
    kInstruction_tst_cc_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r1),
    kInstruction_tst_cc_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r2),
    kInstruction_tst_cc_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r3),
    kInstruction_tst_cc_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r4),
    kInstruction_tst_cc_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r5),
    kInstruction_tst_cc_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r6),
    kInstruction_tst_cc_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r1_r7),
    kInstruction_tst_cc_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r0),
    kInstruction_tst_cc_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r1),
    kInstruction_tst_cc_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r2),
    kInstruction_tst_cc_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r3),
    kInstruction_tst_cc_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r4),
    kInstruction_tst_cc_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r5),
    kInstruction_tst_cc_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r6),
    kInstruction_tst_cc_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r2_r7),
    kInstruction_tst_cc_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r0),
    kInstruction_tst_cc_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r1),
    kInstruction_tst_cc_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r2),
    kInstruction_tst_cc_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r3),
    kInstruction_tst_cc_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r4),
    kInstruction_tst_cc_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r5),
    kInstruction_tst_cc_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r6),
    kInstruction_tst_cc_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r3_r7),
    kInstruction_tst_cc_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r0),
    kInstruction_tst_cc_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r1),
    kInstruction_tst_cc_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r2),
    kInstruction_tst_cc_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r3),
    kInstruction_tst_cc_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r4),
    kInstruction_tst_cc_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r5),
    kInstruction_tst_cc_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r6),
    kInstruction_tst_cc_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r4_r7),
    kInstruction_tst_cc_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r0),
    kInstruction_tst_cc_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r1),
    kInstruction_tst_cc_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r2),
    kInstruction_tst_cc_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r3),
    kInstruction_tst_cc_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r4),
    kInstruction_tst_cc_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r5),
    kInstruction_tst_cc_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r6),
    kInstruction_tst_cc_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r5_r7),
    kInstruction_tst_cc_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r0),
    kInstruction_tst_cc_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r1),
    kInstruction_tst_cc_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r2),
    kInstruction_tst_cc_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r3),
    kInstruction_tst_cc_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r4),
    kInstruction_tst_cc_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r5),
    kInstruction_tst_cc_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r6),
    kInstruction_tst_cc_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r6_r7),
    kInstruction_tst_cc_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r0),
    kInstruction_tst_cc_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r1),
    kInstruction_tst_cc_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r2),
    kInstruction_tst_cc_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r3),
    kInstruction_tst_cc_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r4),
    kInstruction_tst_cc_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r5),
    kInstruction_tst_cc_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r6),
    kInstruction_tst_cc_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_cc_r7_r7),
    kInstruction_tst_cc_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r0),
    kInstruction_tst_mi_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r1),
    kInstruction_tst_mi_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r2),
    kInstruction_tst_mi_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r3),
    kInstruction_tst_mi_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r4),
    kInstruction_tst_mi_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r5),
    kInstruction_tst_mi_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r6),
    kInstruction_tst_mi_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r0_r7),
    kInstruction_tst_mi_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r0),
    kInstruction_tst_mi_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r1),
    kInstruction_tst_mi_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r2),
    kInstruction_tst_mi_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r3),
    kInstruction_tst_mi_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r4),
    kInstruction_tst_mi_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r5),
    kInstruction_tst_mi_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r6),
    kInstruction_tst_mi_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r1_r7),
    kInstruction_tst_mi_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r0),
    kInstruction_tst_mi_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r1),
    kInstruction_tst_mi_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r2),
    kInstruction_tst_mi_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r3),
    kInstruction_tst_mi_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r4),
    kInstruction_tst_mi_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r5),
    kInstruction_tst_mi_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r6),
    kInstruction_tst_mi_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r2_r7),
    kInstruction_tst_mi_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r0),
    kInstruction_tst_mi_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r1),
    kInstruction_tst_mi_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r2),
    kInstruction_tst_mi_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r3),
    kInstruction_tst_mi_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r4),
    kInstruction_tst_mi_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r5),
    kInstruction_tst_mi_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r6),
    kInstruction_tst_mi_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r3_r7),
    kInstruction_tst_mi_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r0),
    kInstruction_tst_mi_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r1),
    kInstruction_tst_mi_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r2),
    kInstruction_tst_mi_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r3),
    kInstruction_tst_mi_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r4),
    kInstruction_tst_mi_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r5),
    kInstruction_tst_mi_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r6),
    kInstruction_tst_mi_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r4_r7),
    kInstruction_tst_mi_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r0),
    kInstruction_tst_mi_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r1),
    kInstruction_tst_mi_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r2),
    kInstruction_tst_mi_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r3),
    kInstruction_tst_mi_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r4),
    kInstruction_tst_mi_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r5),
    kInstruction_tst_mi_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r6),
    kInstruction_tst_mi_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r5_r7),
    kInstruction_tst_mi_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r0),
    kInstruction_tst_mi_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r1),
    kInstruction_tst_mi_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r2),
    kInstruction_tst_mi_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r3),
    kInstruction_tst_mi_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r4),
    kInstruction_tst_mi_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r5),
    kInstruction_tst_mi_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r6),
    kInstruction_tst_mi_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r6_r7),
    kInstruction_tst_mi_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r0),
    kInstruction_tst_mi_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r1),
    kInstruction_tst_mi_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r2),
    kInstruction_tst_mi_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r3),
    kInstruction_tst_mi_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r4),
    kInstruction_tst_mi_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r5),
    kInstruction_tst_mi_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r6),
    kInstruction_tst_mi_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_mi_r7_r7),
    kInstruction_tst_mi_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r0),
    kInstruction_tst_pl_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r1),
    kInstruction_tst_pl_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r2),
    kInstruction_tst_pl_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r3),
    kInstruction_tst_pl_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r4),
    kInstruction_tst_pl_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r5),
    kInstruction_tst_pl_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r6),
    kInstruction_tst_pl_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r0_r7),
    kInstruction_tst_pl_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r0),
    kInstruction_tst_pl_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r1),
    kInstruction_tst_pl_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r2),
    kInstruction_tst_pl_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r3),
    kInstruction_tst_pl_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r4),
    kInstruction_tst_pl_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r5),
    kInstruction_tst_pl_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r6),
    kInstruction_tst_pl_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r1_r7),
    kInstruction_tst_pl_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r0),
    kInstruction_tst_pl_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r1),
    kInstruction_tst_pl_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r2),
    kInstruction_tst_pl_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r3),
    kInstruction_tst_pl_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r4),
    kInstruction_tst_pl_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r5),
    kInstruction_tst_pl_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r6),
    kInstruction_tst_pl_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r2_r7),
    kInstruction_tst_pl_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r0),
    kInstruction_tst_pl_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r1),
    kInstruction_tst_pl_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r2),
    kInstruction_tst_pl_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r3),
    kInstruction_tst_pl_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r4),
    kInstruction_tst_pl_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r5),
    kInstruction_tst_pl_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r6),
    kInstruction_tst_pl_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r3_r7),
    kInstruction_tst_pl_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r0),
    kInstruction_tst_pl_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r1),
    kInstruction_tst_pl_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r2),
    kInstruction_tst_pl_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r3),
    kInstruction_tst_pl_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r4),
    kInstruction_tst_pl_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r5),
    kInstruction_tst_pl_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r6),
    kInstruction_tst_pl_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r4_r7),
    kInstruction_tst_pl_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r0),
    kInstruction_tst_pl_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r1),
    kInstruction_tst_pl_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r2),
    kInstruction_tst_pl_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r3),
    kInstruction_tst_pl_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r4),
    kInstruction_tst_pl_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r5),
    kInstruction_tst_pl_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r6),
    kInstruction_tst_pl_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r5_r7),
    kInstruction_tst_pl_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r0),
    kInstruction_tst_pl_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r1),
    kInstruction_tst_pl_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r2),
    kInstruction_tst_pl_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r3),
    kInstruction_tst_pl_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r4),
    kInstruction_tst_pl_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r5),
    kInstruction_tst_pl_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r6),
    kInstruction_tst_pl_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r6_r7),
    kInstruction_tst_pl_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r0),
    kInstruction_tst_pl_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r1),
    kInstruction_tst_pl_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r2),
    kInstruction_tst_pl_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r3),
    kInstruction_tst_pl_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r4),
    kInstruction_tst_pl_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r5),
    kInstruction_tst_pl_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r6),
    kInstruction_tst_pl_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_pl_r7_r7),
    kInstruction_tst_pl_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r0),
    kInstruction_tst_vs_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r1),
    kInstruction_tst_vs_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r2),
    kInstruction_tst_vs_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r3),
    kInstruction_tst_vs_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r4),
    kInstruction_tst_vs_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r5),
    kInstruction_tst_vs_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r6),
    kInstruction_tst_vs_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r0_r7),
    kInstruction_tst_vs_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r0),
    kInstruction_tst_vs_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r1),
    kInstruction_tst_vs_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r2),
    kInstruction_tst_vs_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r3),
    kInstruction_tst_vs_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r4),
    kInstruction_tst_vs_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r5),
    kInstruction_tst_vs_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r6),
    kInstruction_tst_vs_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r1_r7),
    kInstruction_tst_vs_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r0),
    kInstruction_tst_vs_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r1),
    kInstruction_tst_vs_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r2),
    kInstruction_tst_vs_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r3),
    kInstruction_tst_vs_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r4),
    kInstruction_tst_vs_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r5),
    kInstruction_tst_vs_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r6),
    kInstruction_tst_vs_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r2_r7),
    kInstruction_tst_vs_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r0),
    kInstruction_tst_vs_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r1),
    kInstruction_tst_vs_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r2),
    kInstruction_tst_vs_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r3),
    kInstruction_tst_vs_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r4),
    kInstruction_tst_vs_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r5),
    kInstruction_tst_vs_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r6),
    kInstruction_tst_vs_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r3_r7),
    kInstruction_tst_vs_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r0),
    kInstruction_tst_vs_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r1),
    kInstruction_tst_vs_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r2),
    kInstruction_tst_vs_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r3),
    kInstruction_tst_vs_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r4),
    kInstruction_tst_vs_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r5),
    kInstruction_tst_vs_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r6),
    kInstruction_tst_vs_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r4_r7),
    kInstruction_tst_vs_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r0),
    kInstruction_tst_vs_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r1),
    kInstruction_tst_vs_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r2),
    kInstruction_tst_vs_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r3),
    kInstruction_tst_vs_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r4),
    kInstruction_tst_vs_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r5),
    kInstruction_tst_vs_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r6),
    kInstruction_tst_vs_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r5_r7),
    kInstruction_tst_vs_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r0),
    kInstruction_tst_vs_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r1),
    kInstruction_tst_vs_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r2),
    kInstruction_tst_vs_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r3),
    kInstruction_tst_vs_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r4),
    kInstruction_tst_vs_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r5),
    kInstruction_tst_vs_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r6),
    kInstruction_tst_vs_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r6_r7),
    kInstruction_tst_vs_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r0),
    kInstruction_tst_vs_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r1),
    kInstruction_tst_vs_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r2),
    kInstruction_tst_vs_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r3),
    kInstruction_tst_vs_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r4),
    kInstruction_tst_vs_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r5),
    kInstruction_tst_vs_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r6),
    kInstruction_tst_vs_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vs_r7_r7),
    kInstruction_tst_vs_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r0),
    kInstruction_tst_vc_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r1),
    kInstruction_tst_vc_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r2),
    kInstruction_tst_vc_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r3),
    kInstruction_tst_vc_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r4),
    kInstruction_tst_vc_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r5),
    kInstruction_tst_vc_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r6),
    kInstruction_tst_vc_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r0_r7),
    kInstruction_tst_vc_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r0),
    kInstruction_tst_vc_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r1),
    kInstruction_tst_vc_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r2),
    kInstruction_tst_vc_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r3),
    kInstruction_tst_vc_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r4),
    kInstruction_tst_vc_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r5),
    kInstruction_tst_vc_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r6),
    kInstruction_tst_vc_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r1_r7),
    kInstruction_tst_vc_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r0),
    kInstruction_tst_vc_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r1),
    kInstruction_tst_vc_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r2),
    kInstruction_tst_vc_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r3),
    kInstruction_tst_vc_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r4),
    kInstruction_tst_vc_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r5),
    kInstruction_tst_vc_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r6),
    kInstruction_tst_vc_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r2_r7),
    kInstruction_tst_vc_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r0),
    kInstruction_tst_vc_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r1),
    kInstruction_tst_vc_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r2),
    kInstruction_tst_vc_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r3),
    kInstruction_tst_vc_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r4),
    kInstruction_tst_vc_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r5),
    kInstruction_tst_vc_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r6),
    kInstruction_tst_vc_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r3_r7),
    kInstruction_tst_vc_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r0),
    kInstruction_tst_vc_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r1),
    kInstruction_tst_vc_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r2),
    kInstruction_tst_vc_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r3),
    kInstruction_tst_vc_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r4),
    kInstruction_tst_vc_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r5),
    kInstruction_tst_vc_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r6),
    kInstruction_tst_vc_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r4_r7),
    kInstruction_tst_vc_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r0),
    kInstruction_tst_vc_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r1),
    kInstruction_tst_vc_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r2),
    kInstruction_tst_vc_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r3),
    kInstruction_tst_vc_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r4),
    kInstruction_tst_vc_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r5),
    kInstruction_tst_vc_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r6),
    kInstruction_tst_vc_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r5_r7),
    kInstruction_tst_vc_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r0),
    kInstruction_tst_vc_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r1),
    kInstruction_tst_vc_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r2),
    kInstruction_tst_vc_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r3),
    kInstruction_tst_vc_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r4),
    kInstruction_tst_vc_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r5),
    kInstruction_tst_vc_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r6),
    kInstruction_tst_vc_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r6_r7),
    kInstruction_tst_vc_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r0),
    kInstruction_tst_vc_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r1),
    kInstruction_tst_vc_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r2),
    kInstruction_tst_vc_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r3),
    kInstruction_tst_vc_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r4),
    kInstruction_tst_vc_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r5),
    kInstruction_tst_vc_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r6),
    kInstruction_tst_vc_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_vc_r7_r7),
    kInstruction_tst_vc_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r0),
    kInstruction_tst_hi_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r1),
    kInstruction_tst_hi_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r2),
    kInstruction_tst_hi_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r3),
    kInstruction_tst_hi_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r4),
    kInstruction_tst_hi_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r5),
    kInstruction_tst_hi_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r6),
    kInstruction_tst_hi_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r0_r7),
    kInstruction_tst_hi_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r0),
    kInstruction_tst_hi_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r1),
    kInstruction_tst_hi_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r2),
    kInstruction_tst_hi_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r3),
    kInstruction_tst_hi_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r4),
    kInstruction_tst_hi_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r5),
    kInstruction_tst_hi_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r6),
    kInstruction_tst_hi_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r1_r7),
    kInstruction_tst_hi_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r0),
    kInstruction_tst_hi_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r1),
    kInstruction_tst_hi_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r2),
    kInstruction_tst_hi_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r3),
    kInstruction_tst_hi_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r4),
    kInstruction_tst_hi_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r5),
    kInstruction_tst_hi_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r6),
    kInstruction_tst_hi_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r2_r7),
    kInstruction_tst_hi_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r0),
    kInstruction_tst_hi_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r1),
    kInstruction_tst_hi_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r2),
    kInstruction_tst_hi_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r3),
    kInstruction_tst_hi_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r4),
    kInstruction_tst_hi_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r5),
    kInstruction_tst_hi_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r6),
    kInstruction_tst_hi_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r3_r7),
    kInstruction_tst_hi_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r0),
    kInstruction_tst_hi_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r1),
    kInstruction_tst_hi_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r2),
    kInstruction_tst_hi_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r3),
    kInstruction_tst_hi_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r4),
    kInstruction_tst_hi_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r5),
    kInstruction_tst_hi_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r6),
    kInstruction_tst_hi_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r4_r7),
    kInstruction_tst_hi_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r0),
    kInstruction_tst_hi_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r1),
    kInstruction_tst_hi_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r2),
    kInstruction_tst_hi_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r3),
    kInstruction_tst_hi_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r4),
    kInstruction_tst_hi_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r5),
    kInstruction_tst_hi_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r6),
    kInstruction_tst_hi_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r5_r7),
    kInstruction_tst_hi_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r0),
    kInstruction_tst_hi_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r1),
    kInstruction_tst_hi_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r2),
    kInstruction_tst_hi_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r3),
    kInstruction_tst_hi_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r4),
    kInstruction_tst_hi_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r5),
    kInstruction_tst_hi_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r6),
    kInstruction_tst_hi_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r6_r7),
    kInstruction_tst_hi_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r0),
    kInstruction_tst_hi_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r1),
    kInstruction_tst_hi_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r2),
    kInstruction_tst_hi_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r3),
    kInstruction_tst_hi_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r4),
    kInstruction_tst_hi_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r5),
    kInstruction_tst_hi_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r6),
    kInstruction_tst_hi_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_hi_r7_r7),
    kInstruction_tst_hi_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r0),
    kInstruction_tst_ls_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r1),
    kInstruction_tst_ls_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r2),
    kInstruction_tst_ls_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r3),
    kInstruction_tst_ls_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r4),
    kInstruction_tst_ls_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r5),
    kInstruction_tst_ls_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r6),
    kInstruction_tst_ls_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r0_r7),
    kInstruction_tst_ls_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r0),
    kInstruction_tst_ls_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r1),
    kInstruction_tst_ls_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r2),
    kInstruction_tst_ls_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r3),
    kInstruction_tst_ls_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r4),
    kInstruction_tst_ls_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r5),
    kInstruction_tst_ls_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r6),
    kInstruction_tst_ls_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r1_r7),
    kInstruction_tst_ls_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r0),
    kInstruction_tst_ls_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r1),
    kInstruction_tst_ls_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r2),
    kInstruction_tst_ls_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r3),
    kInstruction_tst_ls_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r4),
    kInstruction_tst_ls_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r5),
    kInstruction_tst_ls_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r6),
    kInstruction_tst_ls_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r2_r7),
    kInstruction_tst_ls_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r0),
    kInstruction_tst_ls_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r1),
    kInstruction_tst_ls_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r2),
    kInstruction_tst_ls_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r3),
    kInstruction_tst_ls_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r4),
    kInstruction_tst_ls_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r5),
    kInstruction_tst_ls_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r6),
    kInstruction_tst_ls_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r3_r7),
    kInstruction_tst_ls_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r0),
    kInstruction_tst_ls_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r1),
    kInstruction_tst_ls_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r2),
    kInstruction_tst_ls_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r3),
    kInstruction_tst_ls_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r4),
    kInstruction_tst_ls_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r5),
    kInstruction_tst_ls_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r6),
    kInstruction_tst_ls_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r4_r7),
    kInstruction_tst_ls_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r0),
    kInstruction_tst_ls_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r1),
    kInstruction_tst_ls_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r2),
    kInstruction_tst_ls_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r3),
    kInstruction_tst_ls_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r4),
    kInstruction_tst_ls_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r5),
    kInstruction_tst_ls_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r6),
    kInstruction_tst_ls_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r5_r7),
    kInstruction_tst_ls_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r0),
    kInstruction_tst_ls_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r1),
    kInstruction_tst_ls_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r2),
    kInstruction_tst_ls_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r3),
    kInstruction_tst_ls_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r4),
    kInstruction_tst_ls_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r5),
    kInstruction_tst_ls_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r6),
    kInstruction_tst_ls_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r6_r7),
    kInstruction_tst_ls_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r0),
    kInstruction_tst_ls_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r1),
    kInstruction_tst_ls_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r2),
    kInstruction_tst_ls_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r3),
    kInstruction_tst_ls_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r4),
    kInstruction_tst_ls_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r5),
    kInstruction_tst_ls_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r6),
    kInstruction_tst_ls_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ls_r7_r7),
    kInstruction_tst_ls_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r0),
    kInstruction_tst_ge_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r1),
    kInstruction_tst_ge_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r2),
    kInstruction_tst_ge_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r3),
    kInstruction_tst_ge_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r4),
    kInstruction_tst_ge_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r5),
    kInstruction_tst_ge_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r6),
    kInstruction_tst_ge_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r0_r7),
    kInstruction_tst_ge_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r0),
    kInstruction_tst_ge_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r1),
    kInstruction_tst_ge_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r2),
    kInstruction_tst_ge_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r3),
    kInstruction_tst_ge_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r4),
    kInstruction_tst_ge_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r5),
    kInstruction_tst_ge_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r6),
    kInstruction_tst_ge_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r1_r7),
    kInstruction_tst_ge_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r0),
    kInstruction_tst_ge_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r1),
    kInstruction_tst_ge_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r2),
    kInstruction_tst_ge_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r3),
    kInstruction_tst_ge_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r4),
    kInstruction_tst_ge_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r5),
    kInstruction_tst_ge_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r6),
    kInstruction_tst_ge_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r2_r7),
    kInstruction_tst_ge_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r0),
    kInstruction_tst_ge_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r1),
    kInstruction_tst_ge_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r2),
    kInstruction_tst_ge_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r3),
    kInstruction_tst_ge_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r4),
    kInstruction_tst_ge_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r5),
    kInstruction_tst_ge_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r6),
    kInstruction_tst_ge_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r3_r7),
    kInstruction_tst_ge_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r0),
    kInstruction_tst_ge_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r1),
    kInstruction_tst_ge_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r2),
    kInstruction_tst_ge_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r3),
    kInstruction_tst_ge_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r4),
    kInstruction_tst_ge_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r5),
    kInstruction_tst_ge_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r6),
    kInstruction_tst_ge_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r4_r7),
    kInstruction_tst_ge_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r0),
    kInstruction_tst_ge_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r1),
    kInstruction_tst_ge_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r2),
    kInstruction_tst_ge_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r3),
    kInstruction_tst_ge_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r4),
    kInstruction_tst_ge_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r5),
    kInstruction_tst_ge_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r6),
    kInstruction_tst_ge_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r5_r7),
    kInstruction_tst_ge_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r0),
    kInstruction_tst_ge_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r1),
    kInstruction_tst_ge_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r2),
    kInstruction_tst_ge_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r3),
    kInstruction_tst_ge_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r4),
    kInstruction_tst_ge_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r5),
    kInstruction_tst_ge_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r6),
    kInstruction_tst_ge_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r6_r7),
    kInstruction_tst_ge_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r0),
    kInstruction_tst_ge_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r1),
    kInstruction_tst_ge_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r2),
    kInstruction_tst_ge_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r3),
    kInstruction_tst_ge_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r4),
    kInstruction_tst_ge_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r5),
    kInstruction_tst_ge_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r6),
    kInstruction_tst_ge_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_ge_r7_r7),
    kInstruction_tst_ge_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r0),
    kInstruction_tst_lt_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r1),
    kInstruction_tst_lt_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r2),
    kInstruction_tst_lt_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r3),
    kInstruction_tst_lt_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r4),
    kInstruction_tst_lt_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r5),
    kInstruction_tst_lt_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r6),
    kInstruction_tst_lt_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r0_r7),
    kInstruction_tst_lt_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r0),
    kInstruction_tst_lt_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r1),
    kInstruction_tst_lt_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r2),
    kInstruction_tst_lt_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r3),
    kInstruction_tst_lt_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r4),
    kInstruction_tst_lt_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r5),
    kInstruction_tst_lt_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r6),
    kInstruction_tst_lt_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r1_r7),
    kInstruction_tst_lt_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r0),
    kInstruction_tst_lt_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r1),
    kInstruction_tst_lt_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r2),
    kInstruction_tst_lt_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r3),
    kInstruction_tst_lt_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r4),
    kInstruction_tst_lt_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r5),
    kInstruction_tst_lt_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r6),
    kInstruction_tst_lt_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r2_r7),
    kInstruction_tst_lt_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r0),
    kInstruction_tst_lt_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r1),
    kInstruction_tst_lt_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r2),
    kInstruction_tst_lt_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r3),
    kInstruction_tst_lt_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r4),
    kInstruction_tst_lt_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r5),
    kInstruction_tst_lt_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r6),
    kInstruction_tst_lt_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r3_r7),
    kInstruction_tst_lt_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r0),
    kInstruction_tst_lt_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r1),
    kInstruction_tst_lt_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r2),
    kInstruction_tst_lt_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r3),
    kInstruction_tst_lt_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r4),
    kInstruction_tst_lt_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r5),
    kInstruction_tst_lt_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r6),
    kInstruction_tst_lt_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r4_r7),
    kInstruction_tst_lt_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r0),
    kInstruction_tst_lt_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r1),
    kInstruction_tst_lt_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r2),
    kInstruction_tst_lt_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r3),
    kInstruction_tst_lt_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r4),
    kInstruction_tst_lt_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r5),
    kInstruction_tst_lt_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r6),
    kInstruction_tst_lt_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r5_r7),
    kInstruction_tst_lt_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r0),
    kInstruction_tst_lt_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r1),
    kInstruction_tst_lt_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r2),
    kInstruction_tst_lt_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r3),
    kInstruction_tst_lt_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r4),
    kInstruction_tst_lt_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r5),
    kInstruction_tst_lt_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r6),
    kInstruction_tst_lt_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r6_r7),
    kInstruction_tst_lt_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r0),
    kInstruction_tst_lt_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r1),
    kInstruction_tst_lt_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r2),
    kInstruction_tst_lt_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r3),
    kInstruction_tst_lt_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r4),
    kInstruction_tst_lt_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r5),
    kInstruction_tst_lt_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r6),
    kInstruction_tst_lt_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_lt_r7_r7),
    kInstruction_tst_lt_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r0),
    kInstruction_tst_gt_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r1),
    kInstruction_tst_gt_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r2),
    kInstruction_tst_gt_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r3),
    kInstruction_tst_gt_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r4),
    kInstruction_tst_gt_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r5),
    kInstruction_tst_gt_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r6),
    kInstruction_tst_gt_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r0_r7),
    kInstruction_tst_gt_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r0),
    kInstruction_tst_gt_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r1),
    kInstruction_tst_gt_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r2),
    kInstruction_tst_gt_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r3),
    kInstruction_tst_gt_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r4),
    kInstruction_tst_gt_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r5),
    kInstruction_tst_gt_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r6),
    kInstruction_tst_gt_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r1_r7),
    kInstruction_tst_gt_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r0),
    kInstruction_tst_gt_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r1),
    kInstruction_tst_gt_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r2),
    kInstruction_tst_gt_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r3),
    kInstruction_tst_gt_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r4),
    kInstruction_tst_gt_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r5),
    kInstruction_tst_gt_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r6),
    kInstruction_tst_gt_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r2_r7),
    kInstruction_tst_gt_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r0),
    kInstruction_tst_gt_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r1),
    kInstruction_tst_gt_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r2),
    kInstruction_tst_gt_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r3),
    kInstruction_tst_gt_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r4),
    kInstruction_tst_gt_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r5),
    kInstruction_tst_gt_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r6),
    kInstruction_tst_gt_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r3_r7),
    kInstruction_tst_gt_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r0),
    kInstruction_tst_gt_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r1),
    kInstruction_tst_gt_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r2),
    kInstruction_tst_gt_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r3),
    kInstruction_tst_gt_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r4),
    kInstruction_tst_gt_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r5),
    kInstruction_tst_gt_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r6),
    kInstruction_tst_gt_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r4_r7),
    kInstruction_tst_gt_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r0),
    kInstruction_tst_gt_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r1),
    kInstruction_tst_gt_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r2),
    kInstruction_tst_gt_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r3),
    kInstruction_tst_gt_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r4),
    kInstruction_tst_gt_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r5),
    kInstruction_tst_gt_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r6),
    kInstruction_tst_gt_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r5_r7),
    kInstruction_tst_gt_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r0),
    kInstruction_tst_gt_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r1),
    kInstruction_tst_gt_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r2),
    kInstruction_tst_gt_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r3),
    kInstruction_tst_gt_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r4),
    kInstruction_tst_gt_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r5),
    kInstruction_tst_gt_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r6),
    kInstruction_tst_gt_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r6_r7),
    kInstruction_tst_gt_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r0),
    kInstruction_tst_gt_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r1),
    kInstruction_tst_gt_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r2),
    kInstruction_tst_gt_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r3),
    kInstruction_tst_gt_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r4),
    kInstruction_tst_gt_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r5),
    kInstruction_tst_gt_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r6),
    kInstruction_tst_gt_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_gt_r7_r7),
    kInstruction_tst_gt_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r0),
    kInstruction_tst_le_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r1),
    kInstruction_tst_le_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r2),
    kInstruction_tst_le_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r3),
    kInstruction_tst_le_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r4),
    kInstruction_tst_le_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r5),
    kInstruction_tst_le_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r6),
    kInstruction_tst_le_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r0_r7),
    kInstruction_tst_le_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r0),
    kInstruction_tst_le_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r1),
    kInstruction_tst_le_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r2),
    kInstruction_tst_le_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r3),
    kInstruction_tst_le_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r4),
    kInstruction_tst_le_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r5),
    kInstruction_tst_le_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r6),
    kInstruction_tst_le_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r1_r7),
    kInstruction_tst_le_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r0),
    kInstruction_tst_le_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r1),
    kInstruction_tst_le_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r2),
    kInstruction_tst_le_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r3),
    kInstruction_tst_le_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r4),
    kInstruction_tst_le_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r5),
    kInstruction_tst_le_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r6),
    kInstruction_tst_le_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r2_r7),
    kInstruction_tst_le_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r0),
    kInstruction_tst_le_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r1),
    kInstruction_tst_le_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r2),
    kInstruction_tst_le_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r3),
    kInstruction_tst_le_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r4),
    kInstruction_tst_le_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r5),
    kInstruction_tst_le_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r6),
    kInstruction_tst_le_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r3_r7),
    kInstruction_tst_le_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r0),
    kInstruction_tst_le_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r1),
    kInstruction_tst_le_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r2),
    kInstruction_tst_le_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r3),
    kInstruction_tst_le_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r4),
    kInstruction_tst_le_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r5),
    kInstruction_tst_le_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r6),
    kInstruction_tst_le_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r4_r7),
    kInstruction_tst_le_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r0),
    kInstruction_tst_le_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r1),
    kInstruction_tst_le_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r2),
    kInstruction_tst_le_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r3),
    kInstruction_tst_le_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r4),
    kInstruction_tst_le_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r5),
    kInstruction_tst_le_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r6),
    kInstruction_tst_le_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r5_r7),
    kInstruction_tst_le_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r0),
    kInstruction_tst_le_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r1),
    kInstruction_tst_le_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r2),
    kInstruction_tst_le_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r3),
    kInstruction_tst_le_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r4),
    kInstruction_tst_le_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r5),
    kInstruction_tst_le_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r6),
    kInstruction_tst_le_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r6_r7),
    kInstruction_tst_le_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r0),
    kInstruction_tst_le_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r1),
    kInstruction_tst_le_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r2),
    kInstruction_tst_le_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r3),
    kInstruction_tst_le_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r4),
    kInstruction_tst_le_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r5),
    kInstruction_tst_le_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r6),
    kInstruction_tst_le_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_tst_le_r7_r7),
    kInstruction_tst_le_r7_r7,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_RN_LOW_REGISTERS_IN_IT_BLOCK_TST_T32_H_
